clear
clear mata
clear matrix
set more 1

*** program to windsorize outliers in beta distribution before computing aggregates.
program define windso
cap drop p99 
quietly egen p99=pctile(`1'), p(99) by(date) 
cap drop p1
quietly egen p1=pctile(`1'), p(1) by(date) 
quietly replace `1'=p99 if `1'>p99&`1'~=.
quietly replace `1'=p1 if `1'<p1&`1'~=.
end


********************************************************************************
**************** Defines various proxies for aggregate disagreement
********************************************************************************
cap program drop construc_aggregate
program define construc_aggregate

	
	quietly{
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	**** use only beta weights
	windso beta_daily
	gen weight=abs(beta_daily)
 	collapse (mean) aggregate_disp_daily=stdevwin aggregate_mean_daily=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_daily)
 	egen s=sd(aggregate_disp_daily)
 	replace aggregate_disp_daily=(aggregate_disp_daily-m)/s
 	drop m s
 	sort date
 	save "../output/aggregate_disp", replace

		
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	**** use only beta weights but shrink beta estimates
	windso beta_daily
	gen weight=abs(.5*beta_daily+.5)
 	collapse (mean) aggregate_disp_daily2=stdevwin aggregate_mean_daily2=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_daily2)
 	egen s=sd(aggregate_disp_daily2)
 	replace aggregate_disp_daily2=(aggregate_disp_daily2-m)/s
 	drop m s
 	sort date
 	merge 1:1 date using "../output/aggregate_disp"
	drop if _m==1
	drop _m
 	sort date
 	save "../output/aggregate_disp", replace

	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	keep if nyse==1
	**** use only beta weights but shrink beta estimates
	windso beta_daily
	gen weight=abs(beta_daily)
 	collapse (mean) aggregate_disp_daily4=stdevwin aggregate_mean_daily4=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_daily4)
 	egen s=sd(aggregate_disp_daily4)
 	replace aggregate_disp_daily4=(aggregate_disp_daily4-m)/s
 	drop m s
 	sort date
 	merge 1:1 date using "../output/aggregate_disp"
	drop if _m==1
	drop _m
 	sort date
 	save "../output/aggregate_disp", replace 
	
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	**** use value and beta weights
	windso beta_daily
	gen weight=abs(beta_daily)*abs(value)
 	collapse (mean) aggregate_disp_daily3=stdevwin aggregate_mean_daily3=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_daily3)
 	egen s=sd(aggregate_disp_daily3)
 	replace aggregate_disp_daily3=(aggregate_disp_daily3-m)/s
 	drop m s

 	sort date
 	merge 1:1 date using "../output/aggregate_disp"
	drop if _m==1
	drop _m
	gen date2=year(date)*12+month(date)
 	sort date2
 	save "../output/aggregate_disp", replace
	
	
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	**** use only beta weights
	windso beta_monthly
	gen weight=abs(beta_monthly)
 	collapse (mean) aggregate_disp_monthly=stdevwin aggregate_mean_monthly=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_monthly)
 	egen s=sd(aggregate_disp_monthly)
 	replace aggregate_disp_monthly=(aggregate_disp_monthly-m)/s
 	drop m s
 	sort date
 	save "../output/temp", replace

	
	
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	**** use only beta weights but shrink beta estimates
	windso beta_monthly
	gen weight=abs(.5*beta_monthly+.5)
 	collapse (mean) aggregate_disp_monthly2=stdevwin aggregate_mean_monthly2=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_monthly2)
 	egen s=sd(aggregate_disp_monthly2)
 	replace aggregate_disp_monthly2=(aggregate_disp_monthly2-m)/s
 	drop m s
 	sort date
 	merge 1:1 date using "../output/temp"
	drop if _m==1
	drop _m
 	sort date
 	save "../output/temp", replace

	
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	**** use value and beta weights
	windso beta_monthly
	gen weight=abs(beta_monthly)*abs(value)
 	collapse (mean) aggregate_disp_monthly3=stdevwin aggregate_mean_monthly3=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_monthly3)
 	egen s=sd(aggregate_disp_monthly3)
 	replace aggregate_disp_monthly3=(aggregate_disp_monthly3-m)/s
 	drop m s

 	sort date
 	merge 1:1 date using "../output/temp"
	drop if _m==1
	drop _m
	gen date2=year(date)*12+month(date)
 	sort date2
 	keep date2 aggregate_disp* aggregate_mean*
	merge 1:1 date2 using  "../output/aggregate_disp"
	drop if _m==2
	drop _m
	sort date2
 	save "../output/aggregate_disp", replace

	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	sort permno year month
	merge 1:1 permno year month using "../output monthly/betas_total_CF"
	drop if _m==2
	drop _m
	**** use only beta weights
	windso beta_CF
	gen weight=abs(beta_CF)
 	collapse (mean) aggregate_disp_CF=stdevwin aggregate_mean_daily=meanestwin [w=weight], by(date)
 	egen m=mean(aggregate_disp_CF)
 	egen s=sd(aggregate_disp_CF)
 	replace aggregate_disp_CF=(aggregate_disp_CF-m)/s
 	drop m s
 	gen date2=year(date)*12+month(date)
 	sort date2
	merge 1:1 date2 using  "../output/aggregate_disp"
	drop if _m==1
	drop _m
	sort date2
 	save "../output/aggregate_disp", replace
} 	 	


end

