clear
clear mata
clear matrix
set mem 5g
set more 1

cap program drop beta
program define beta
syntax [if] [in] 

********************************************************************************
**********************	CONSTRUCT BETA			********************************
********************************************************************************
	

quietly {	
			***************************************************************
			*********************First create a dataset *******************
			*********************with daily FFfactors *********************
			***************************************************************
						
	insheet using "../source/F-F_Research_Data_Factors_daily.txt",names tab clear
	gen year=int(date/10000)
	gen month=int((date-10000*year)/100)
	gen day=date-10000*year-100*month
	gen date2=mdy(month,day,year)
	drop month day year
	drop date
	ren date2 date
	keep if date~=.
	keep mktrf rf date
	sort date
	egen DATE=group(date)
	tsset DATE
	forvalues i=1(1)5{
		gen mktrf`i'=L`i'.mktrf
	}
	drop DATE
	sort date
	save "../output/factors",replace     
	
	
			***************************************************************
			*********************construct 6 CRSP samples******************
			*********************designed to do daily CAPM regressions*****
			***************************************************************

	use ../source/CRSP50_70.dta,clear
	keep if year(date)>=1961
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP61_70.dta,replace


	use ../source/CRSP69_79.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP69_79.dta,replace


	use ../source/CRSP80_90.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP80_90.dta,replace
	
	
	use ../source/CRSP91_96.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP91_96.dta,replace
	
	
	use ../source/CRSP97_02.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP97_02.dta,replace
	
	
	use ../source/CRSP03_10.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP03_10.dta,replace

	
	use ../source/CRSP11_12.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP11_12.dta,replace
	
	use ../source/CRSP13_14.dta,clear
	sort date
	merge m:1 date using "../output/factors"
	drop if _m==2
	drop _m
	gen ret_rf=100*ret-rf
	keep date ret_rf mktrf* permno
	sort date
	save ../output/CRSP13_14.dta,replace


			***************************************************************
			*********************Need to create interim *******************
			*********************datasets for first years******************
			*********************of sub-CRSP sample		 ******************
			***************************************************************

	use if year(date)==1979 using ../output/CRSP69_79.dta,clear
	save "../output/temp", replace
	use if year(date)==1980 using ../output/CRSP80_90.dta,clear
	append using "../output/temp"
	sort date
	save ../output/CRSP79_80, replace
	
	use if year(date)==1990 using ../output/CRSP80_90.dta,clear
	save "../output/temp", replace
	use if year(date)==1991 using ../output/CRSP91_96.dta,clear
	append using "../output/temp"
	sort date
	save ../output/CRSP90_91, replace
	
	use if year(date)==1996 using ../output/CRSP91_96.dta,clear
	save "../output/temp", replace
	use if year(date)==1997 using ../output/CRSP97_02.dta,clear
	append using "../output/temp"
	sort date
	save ../output/CRSP96_97, replace
	
	use if year(date)==2002 using ../output/CRSP97_02.dta,clear
	save "../output/temp", replace
	use if year(date)==2003 using ../output/CRSP03_10.dta,clear
	append using "../output/temp"
	sort date
	save ../output/CRSP02_03, replace

	use if year(date)==2010 using ../output/CRSP03_10.dta,clear
	save "../output/temp", replace
	use if year(date)==2011 using ../output/CRSP11_12.dta,clear
	append using "../output/temp"
	sort date
	save ../output/CRSP10_11, replace

	
	use if year(date)==2012 using ../output/CRSP11_12.dta,clear
	save "../output/temp", replace
	use if year(date)==2013 using ../output/CRSP13_14.dta,clear
	append using "../output/temp"
	sort date
	save ../output/CRSP12_13, replace
	
	capture erase "../output/temp.dta" 

			***************************************************************
			*********************loop to compute betas  *******************
			*********************using statsby			 ******************
			***************************************************************

	*****1962 to 1970
	local k=1962*12+1
	local l=1970*12+12
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP61_70.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
			quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}

	*****1971 to 1979
	local k=1971*12+1
	local l=1979*12+12
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP69_79.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
			quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}


	***1980
	local k=1980*12+1
	local l=1980*12+12
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP79_80.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}

	
	*****1981 to 1990
	local k=1981*12+1
	local l=1990*12+12
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP80_90.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
			quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}
	
	***1991
	local k=1991*12+1
	local l=1991*12+12
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP90_91.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}
	
	***1992 to 1996
	local k=1992*12+1
	local l=1996*12+12
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP91_96.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
		
		}
	
	
	***1997
	local k=1997*12+1
	local l=1997*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP96_97.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}
	
	***1998 to 2002
	
	local k=1998*12+1
	local l=2002*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP97_02.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
		
		}
	
	
	***2003
	
	local k=2003*12+1
	local l=2003*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly	use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP02_03.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
			quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
			
		}
	
	***2004 to 2010
	
	local k=2004*12+1
	local l=2010*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP03_10.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5

		}

	***2011
	
	local k=2011*12+1
	local l=2011*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP10_11.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
		
		}

	***2012
	
	local k=2012*12+1
	local l=2012*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP11_12.dta,clear
		quietly drop date
		if 	("`clean'"=="clean"){
			clean ret_rf
			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
		
		}


	***2013
	local k=2013*12+1
	local l=2013*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP12_13.dta,clear
		quietly drop date
*		if 	("`clean'"=="clean"){
*			clean ret_rf
*			}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
		
		}

		
	***2014
	
	local k=2014*12+1
	local l=2014*12+12
	
	forvalues i=`k'(1)`l'{
		disp `i'
		quietly use date permno ret_rf mktrf* if year(date)*12+month(date)<=`i'&year(date)*12+month(date)>`i'-12 using ../output/CRSP13_14.dta,clear
		quietly drop date
		*if 	("`clean'"=="clean"){
		*	clean ret_rf
		*	}
		quietly statsby _b e(rmse), by(permno) saving(../output/betas`i', replace) nodots: reg ret_rf  mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5
		
		}
		
			***************************************************************
			*********************aggregate beta samples *******************
			***************************************************************

	clear 
	gen x=.
	save ../output/betas_total, replace
	
	local k=1962*12+2
	local l=2012*12+12
	local j=1962*12+1
	use ../output/betas`j', replace
	forvalues i=`k'(1)`l'{
		quietly use ../output/betas`i', replace
		quietly gen date2=`i'
		quietly append using ../output/betas_total
		quietly save ../output/betas_total, replace
	}
	
	local k=2013*12+1
	local l=2014*12+12
	forvalues i=`k'(1)`l'{
		quietly use ../output/betas`i', replace
		quietly gen date2=`i'
		quietly append using ../output/betas_total
		quietly save ../output/betas_total, replace
	}
	
	gen beta=_b_mktrf+_b_mktrf1+_b_mktrf2+_b_mktrf3+_b_mktrf4+_b_mktrf5
	gen sigma=_eq2_stat_1
	gen year=int((date2-1)/12)
	gen month=date2-12*year
	keep beta sigma year month date2 permno
	sort permno date
	save ../output/betas_total, replace


}

end
