clear
clear mata
clear matrix
set mem 5g
set more 1

cd "/Users/davidsraer/Dropbox/Speculative betas/revision2/progs"


			* 	THIS PROGRAM CREATES TWO DATASETS							*
			* 1) 20 CASH FLOW BETA-SORTED PORTFOLIOS USING NYSE BREAKPOINTS *
			* 2) 20 CASH FLOW BETA SORTED PORTFOLIOS FOR SPECULATIVE AND NON*
			* SPECULATIVE STOCKS, USING NYSE BREAKPOINTS AND SPECULATIVE IS *
			* DEFINED AS ABOVE MEDIAN NYSE CASH FLOW BETA/SIGMA^2			*	
			* PORTFOLIOS ARE VALUE WEIGHTED									*	
			* PROGRAM ALSO COMPUTES POST-RANKING CASH FLOW BETA				*
			

	* start from stock-level sample with information on return
	use "../output/stock_monthly_beta",replace
	
	* merge with sample containing cash flow and discount beta
	sort permno year month
	merge 1:1 permno year month using "../output monthly/betas_total_CF"
	drop if _m==2
	drop _m
	* drop penny stocks (price<$5)
	drop if penny==1
	* drop microcaps (bottom 20% of monthly size distribution using NYSE breakpoints)
	drop if microcap==1
	* rename cash flow beta as "monthly beta"
	drop beta_monthly beta_daily
	ren beta_CF beta_monthly
	
	* BB is CF Beta for NYSE stocks only
	gen BB=beta_monthly if nyse==1
	* BB2 is CF Beta for all stocks
	gen BB2=beta_monthly 
	
	* construct 20 thresholds of nyse cash flow betas
	forvalues i=5(5)95{
	cap drop p`i'
	egen p`i'=pctile(BB), p(`i') by(date)
	}
	* allocate all stocks to these 20 bins
	gen group=1 if BB2<p5&BB2~=.
	forvalues i=10(5)95{
		local j=`i'-5
		replace group=(`i')/5 if BB2<p`i'&BB2>=p`j'&BB2~=.
		}
	replace group=20 if BB2>=p95&BB2~=.
	* store in local
	sort group date
	save "../output/local", replace
		
	* NEED TO COMPUTE POST RANKING CASH FLOW BETA
	collapse (mean) ret , by(group date year month)
	sort year month
	merge m:1 year month using ../output/factors_CV
	* construct covariances as in CAMPBELL and VOLTHUENAO
	drop if _m==2
	drop _m
	* COVARIANCE OF return and CF NEWS
	* VARIANCE of  CF NEWS-risk-free rate
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(ncf) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(ncf-x2)  if ret~=.&ncf~=.&nr~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2 if ret~=.&ncf~=.&nr~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp1
	quietly  gen temp1=S1/S2
	
	* COVARIANCE OF return and lagged CF NEWS
	* VARIANCE of  CF NEWS-risk-free rate
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&ncf_1~=.&nr~=.&ncf~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(ncf_1) if ret~=.&ncf_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(ncf_1-x2)  if ret~=.&ncf_1~=.&nr~=.&ncf~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&ncf_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2  if ret~=.&ncf_1~=.&nr~=.&ncf~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp2
	quietly  gen temp2=S1/S2 
	gen BETA_CF=temp1+temp2	
	
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(nr) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(nr-x2)  if ret~=.&ncf~=.&nr~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2 if ret~=.&ncf~=.&nr~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp1
	quietly  gen temp1=S1/S2 
	
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&nr_1~=.&nr~=.&ncf~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(nr_1) if ret~=.&nr_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(nr_1-x2)  if ret~=.&nr_1~=.&nr~=.&ncf~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&nr_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2  if ret~=.&nr_1~=.&nr~=.&ncf~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp2
	quietly  gen temp2=S1/S2
	gen BETA_DR=temp1+temp2	
	bys group: keep if _n==1
	keep group BETA_DR BETA_CF
	sort group
	merge 1:m group using "../output/local"
	drop if _m==2
	drop _m
	
	sort group year month
	save "../output/sample_vw_all_beta_monthly_breakpoint_CV", replace	



	
	*****CONSTRUCT WITH THE BETA/SIGMA^2 SORT
	
	use "../output/stock_monthly_beta",replace
	drop if penny==1
	drop if microcap==1
	sort permno year month
	merge 1:1 permno year month using "../output monthly/betas_total_CF"
	drop if _m==2
	drop _m
	drop beta_monthly beta_daily
	ren beta_CF beta_monthly
	
	gen BB=beta_monthly if nyse==1
	gen SS=sigma_monthly if nyse==1

	
	***each month we sort stocks into two groups of beta over sigma^2
	cap drop temp
	gen temp=BB/(SS^2)
	
	cap drop cut
	egen cut=pctile(temp), p(50) by(date)
	drop BB SS
	gen BB=beta_monthly
	gen SS=sigma_monthly

	gen spec=1 if BB/(SS^2)>cut &BB/(SS^2)~=.
	replace spec=0 if BB/(SS^2)<=cut &BB/(SS^2)~=.
	
	
	*** we construct 20 beta portfolios for each spec group
	gen beta1=beta_monthly if spec==0 & nyse==1
	gen beta2=beta_monthly if spec==1 & nyse==1
	
	
	forvalues i=5(5)95{
	cap drop p`i'
	egen p`i'=pctile(beta1), p(`i') by(date)
	cap drop q`i'
	egen q`i'=pctile(beta2), p(`i') by(date)
	}
	
	gen group=1 if beta_monthly<p5&beta_monthly~=.&spec==0
	forvalues i=10(5)95{
		local j=`i'-5
		replace group=(`i')/5 if beta_monthly<p`i'&beta_monthly>=p`j'&beta_monthly~=.&spec==0
		}
	replace group=20 if beta_monthly>=p95&beta_monthly~=.&spec==0
	
	replace group=21 if beta_monthly<q5&beta_monthly~=.&spec==1
	forvalues i=10(5)95{
		local j=`i'-5
		replace group=20+(`i')/5 if beta_monthly<q`i'&beta_monthly>=q`j'&beta_monthly~=.&spec==1
		}
	replace group=40 if beta_monthly>=q95&beta_monthly~=.&spec==1

	
	sort group date
	save "../output/local", replace
	
	****COMPUTING POST RANKING BETA CF
	
	collapse (mean) ret , by(group date year month)
	
	sort year month
	merge m:1 year month using ../output/factors_CV
	****covariance of 
	drop if _m==2
	drop _m
	
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(ncf) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(ncf-x2)  if ret~=.&ncf~=.&nr~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2 if ret~=.&ncf~=.&nr~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp1
	quietly  gen temp1=S1/S2
	
quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&ncf_1~=.&nr~=.&ncf~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(ncf_1) if ret~=.&ncf_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(ncf_1-x2)  if ret~=.&ncf_1~=.&nr~=.&ncf~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&ncf_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2  if ret~=.&ncf_1~=.&nr~=.&ncf~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp2
	quietly  gen temp2=S1/S2 
	gen BETA_CF=temp1+temp2	
	
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(nr) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(nr-x2)  if ret~=.&ncf~=.&nr~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&ncf~=.&nr~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2 if ret~=.&ncf~=.&nr~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp1
	quietly  gen temp1=S1/S2 
	
	quietly cap drop x1
	quietly egen x1=mean(ret) if ret~=.&nr_1~=.&nr~=.&ncf~=.,by(group)
	quietly cap drop x2
	quietly egen x2=mean(nr_1) if ret~=.&nr_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop xy
	quietly  gen xy=(ret-x1)*(nr_1-x2)  if ret~=.&nr_1~=.&nr~=.&ncf~=.
	cap drop x3
	quietly egen x3=mean(ncf-nr) if ret~=.&nr_1~=.&nr~=.&ncf~=.,by(group)
	quietly  cap drop X2
	quietly  gen X2=(ncf-nr-x3)^2  if ret~=.&nr_1~=.&nr~=.&ncf~=.
	quietly  cap drop S1
	quietly  egen S1=sum(xy),by(group)
	quietly  cap drop S2
	quietly  egen S2=sum(X2),by(group)
	quietly  cap drop N1
	quietly  egen N1=count(xy),by(group)
	quietly  cap drop N2
	quietly  egen N2=count(X2),by(group)
	quietly cap drop temp2
	quietly  gen temp2=S1/S2
	gen BETA_DR=temp1+temp2	
	bys group: keep if _n==1
	keep group BETA_DR BETA_CF
	sort group
	merge 1:m group using "../output/local"
	drop if _m==2
	drop _m
	
	sort group year month
	save "../output/sample_vw_50_monthly_breakpoints_CV", replace	



	
