clear
clear mata
clear matrix
set mem 5g
set more 1

cd "/Users/davidsraer/Dropbox/Speculative betas/revision2/progs"


				**************************************************
				* 		THIS PROGRAM CREATES 40 PORTFOLIOS		 *
				* 	1) 20 BETA-SORTED PORTFOLIOS AMONG STOCKS    *
				* 		 WITH LOW PRE-RANKING BETA/SIGMA^2 		 *
				* 	2) 20 BETA-SORTED PORTFOLIOS AMONG STOCKS    *
				* 		 WITH HIGH PRE-RANKING BETA/SIGMA^2 	 *
				* 			THIS DATASET INCLUDES MICROCAPS 	 *
				* THREE OPTIONS: 
				* (1) value or equal-weighted portfolios	 	 *
				* (2) monthly or daily returns for computing beta*
				* (3) threshold to define high and low beta/sigma*
				**************************************************

				
cap program drop construc_data1_breakpoints_micro
program define construc_data1_breakpoints_micro
* `anything' will be percentile used to define speculative stocks
syntax anything [if] [in] [,VALue MONthly]

quietly{
	* start from stock-level sample with monthly and daily betas and returns	
	use "../output/stock_monthly_beta",replace
	* drop penny stocks (price<$5)
	drop if penny==1
			
	* BB and SS are betas and idio vol for NYSE stocks only
	
	* with monthly option
	if "`monthly'"=="monthly"{	
		gen BB=beta_monthly if nyse==1
		gen SS=sigma_monthly if nyse==1
	}
	
	* with daily option
	if "`monthly'"~="monthly"{	
		gen BB=beta_daily if nyse==1
		gen SS=sigma_daily if nyse==1
	}
	
	* temp is ratio of beta over sigma^2 for NYSE stocks
	cap drop temp
	gen temp=BB/(SS^2)
	
	* cut defines the threshold each month for speculative stocks
	* it only uses NYSE stocks since it uses temp
	* cut is the `anything' percentile of beta/sigma^2 distribution of
	* NYSE stocks 
	cap drop cut
	egen cut=pctile(temp), p(`anything') by(date)
	drop BB SS
	* redefine BB and SS to be beta and idio vol for all stocks
	
	* with monthly option
	if "`monthly'"=="monthly"{	
		gen BB=beta_monthly
		gen SS=sigma_monthly
	}
	
	* with daily option
	if "`monthly'"~="monthly"{	
		gen BB=beta_daily
		gen SS=sigma_daily
	}
		
	* define speculative stocks as stocks with beta/sigma^2 above cut
	gen spec=1 if BB/(SS^2)>cut &BB/(SS^2)~=.
	replace spec=0 if BB/(SS^2)<=cut &BB/(SS^2)~=.
	
	* now, we construct 20 beta sorted portfolios for each spec group
	
	* beta1 is beta for NYSE speculative stocks only 
	* beta2 is beta for NYSE non-speculative stocks only
	
	* using daily option
	if "`monthly'"~="monthly"{	
		gen beta1=beta_daily if spec==0 & nyse==1
		gen beta2=beta_daily if spec==1 & nyse==1
	}
	* using monthly option
	if "`monthly'"=="monthly"{	
		gen beta1=beta_monthly if spec==0 & nyse==1
		gen beta2=beta_monthly if spec==1 & nyse==1
	}
	
	* compute 20 breakpoints for distribution of beta of NYSE-speculative stocks
	* compute 20 breakpoints for distribution of beta of NYSE- non speculative stocks
	forvalues i=5(5)95{
		cap drop p`i'
		egen p`i'=pctile(beta1), p(`i') by(date)
		cap drop q`i'
		egen q`i'=pctile(beta2), p(`i') by(date)
	}
	
	* allocate stocks to their respective bins of beta
	* first 20 bins are for non-spec stocks
	* next 20 bins are for spec stocks
	
	*using daily option
	if "`monthly'"~="monthly"{	
		gen group=1 if beta_daily<p5&beta_daily~=.&spec==0
		forvalues i=10(5)95{
			local j=`i'-5
			replace group=(`i')/5 if beta_daily<p`i'&beta_daily>=p`j'&beta_daily~=.&spec==0
			}
		replace group=20 if beta_daily>=p95&beta_daily~=.&spec==0
		replace group=21 if beta_daily<q5&beta_daily~=.&spec==1
		forvalues i=10(5)95{
			local j=`i'-5
			replace group=20+(`i')/5 if beta_daily<q`i'&beta_daily>=q`j'&beta_daily~=.&spec==1
			}
		replace group=40 if beta_daily>=q95&beta_daily~=.&spec==1
	}
	
	*using monthly option
	if "`monthly'"=="monthly"{	
		gen group=1 if beta_monthly<p5&beta_monthly~=.&spec==0
		forvalues i=10(5)95{
			local j=`i'-5
			replace group=(`i')/5 if beta_monthly<p`i'&beta_monthly>=p`j'&beta_monthly~=.&spec==0
			}
		replace group=20 if beta_monthly>=p95&beta_monthly~=.&spec==0
		
		replace group=21 if beta_monthly<q5&beta_monthly~=.&spec==1
		forvalues i=10(5)95{
			local j=`i'-5
			replace group=20+(`i')/5 if beta_monthly<q`i'&beta_monthly>=q`j'&beta_monthly~=.&spec==1
			}
		replace group=40 if beta_monthly>=q95&beta_monthly~=.&spec==1
	}
	* save in local
	sort group date
	save "../output/local", replace
	
			*************************************************************	
			*  COMPUTING POST RANKING BETA OF 40 BETA-SORTED PORTFOLIOS *
			*************************************************************
	
	* first when no-monthly option
	* this takes time since need daily observations for all the portfolios
	if "`monthly'"~="monthly"{	
	quietly{
	
		keep permno date group value
		quietly gen date2=year(date)*12+month(date)
		
		* define group (portfolio) as past month portfolio
		* this way, current returns are post-formation returns
		* i.e. 1 month after formation
		tsset permno date2
		quietly gen temp=L.group
		quietly drop group
		quietly gen group=temp
		cap drop temp
		quietly gen temp=L.value
		* we also use previous pre-formation value
		* when doing value weighting
		quietly drop value
		quietly gen value=temp
		quietly drop temp
		quietly drop date2
		quietly gen year=year(date)
		quietly gen month=month(date)
		keep year month group permno value
		
		* for a given year-month, dataset contains end-of-previous month beta group
		* and end-of-previous month value.
		* when we merge with daily returns, each daily return is attached to 
		* end-of-previous month beta portfolio
		
		sort permno year month
		save "../output/temp.dta", replace
			
		* first start with return data from 1980 to 1990 with factors
		* this dataset is created when we compute all the pre-ranking betas at stock
		*level
		use "../output/CRSP80_90.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		sort permno year month
		* merge with end-of-previous month portfolio group and end-of-previous month
		* value
		quietly merge m:1 permno year month using "../output/temp"
		keep if _m==3
		drop _m
		* collapse excess returns and market excess returns at portfolio-day level
		* option for value-weighting
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		* no option for value-weighting
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp2.dta", replace
		
		* repeat for 91-96
		use "../output/CRSP91_96.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		quietly keep if _m==3
		drop _m
		if "`value'"=="value"{	
		quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
		quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		quietly sort group date
		save "../output/temp3.dta", replace

		* repeat for 97-02
		use "../output/CRSP97_02.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		keep if _m==3
		drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp4.dta", replace
		
		* repeat for 03-10
		use "../output/CRSP03_10.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		quietly sort permno year month
		merge m:1 permno year month using "../output/temp"
		keep if _m==3
		drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp5.dta", replace

		* repeat for 11-12
		use "../output/CRSP11_12.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		quietly sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		quietly keep if _m==3
		quietly drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp6.dta", replace

		* repeat for 13-14
		use "../output/CRSP13_14.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		quietly sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		quietly keep if _m==3
		quietly drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		
		* append to all the previous daily portfolio returns computed over 
		* different periods
		quietly append using "../output/temp6.dta"	
		quietly append using "../output/temp5.dta"	
		quietly append using "../output/temp4.dta"	
		quietly append using "../output/temp3.dta"
		quietly append using "../output/temp2.dta"
		
		*BETA_1 will be portfolio BETA over whole sample 	
		cap drop BETA_1
		quietly gen BETA_1=.
		*SIGMA_1 will be portfolio idio. volatility over whole sample 
		cap drop SIGMA_1
		quietly gen SIGMA_1=.
		
		sort group date		

		* loop over each of the portfolios
		quietly levelsof group, local(levels)
		foreach i of local levels {
			* use daily market model with 5 lags over 12/1982 to 12/2014
			reg ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 if group==`i' &year(date)*12+month(date)>=1981*12+12&year(date)<=2014
			replace BETA_1=_b[mktrf]+_b[mktrf1]+_b[mktrf2]+_b[mktrf3]+_b[mktrf4]+_b[mktrf5] if group==`i'
			replace SIGMA_1=e(rmse) if group==`i'
		}
		* keep only one observation per portfolio and only post-ranking beta and vol
		keep group BETA_1 SIGMA_1  
		bys group: keep if _n==1
		* erase temp files
		erase "../output/temp6.dta"	
		erase "../output/temp5.dta"	
		erase "../output/temp4.dta"	
		erase "../output/temp3.dta"
		erase "../output/temp2.dta"	
		erase "../output/temp.dta"
	}
	}
	
	* Computing now post-ranking betas on whole sample with monthly option
	if "`monthly'"=="monthly"{	
		quietly{
		* since this uses monthly return, no need to merge with return data
		* simply use current month excess return by stock
		keep permno date group value ret_rf mktrf
		quietly gen date2=year(date)*12+month(date)
		
		* define group (portfolio) as past month portfolio
		* this way, current returns are post-formation returns
		* i.e. 1 month after formation
		tsset permno date2
		quietly gen temp=L.group
		quietly drop group
		quietly gen group=temp
		* we also use previous pre-formation value
		* when doing value weighting
		cap drop temp
		quietly gen temp=L.value
		quietly drop value
		quietly gen value=temp
		quietly drop temp
		keep date2 date group permno value ret_rf mktrf
		* for a given year-month, dataset contains end-of-previous month beta group
		* and end-of-previous month value.
		* when we merge with daily returns, each daily return is attached to 
		* end-of-previous month beta portfolio
		
		* collapse excess returns at portfolio/month level, value-weighted option
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf  [w=value], by(date group)
		}
		* collapse excess returns at portfolio/month level, equal-weighted option
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf , by(date group)
		}
		*BETA_1 will be portfolio BETA over whole sample 			
		cap drop BETA_1
		quietly gen BETA_1=.
		*SIGMA_1 will be portfolio idio. volatility over whole sample 
		cap drop SIGMA_1
		quietly gen SIGMA_1=.
		sort group date		

		* loop over each of the portfolios
		quietly levelsof group, local(levels)
		foreach i of local levels {
		* use monthly market model with 5 lags over 12/1982 to 12/2014
		reg ret_rf mktrf  if group==`i' &year(date)*12+month(date)>=1981*12+12&year(date)<=2014
		replace BETA_1=_b[mktrf] if group==`i'
		replace SIGMA_1=e(rmse) if group==`i'
		}
		
		keep group BETA_1 SIGMA_1  
		bys group: keep if _n==1
	}
	}
	
	* merge dataset with post-ranking betas with stock-level dataset with
	* portfolio group
	sort group
	merge 1:m group using "../output/local"
	drop if _m==1
	drop _m
	
	* drop if portfolio group is not defined
	drop if group==.
	
	* save dataset with various options.
	sort group year month
	if "`monthly'"~="monthly"{
		if "`value'"~="value"{
		save "../output/sample_ew_`anything'_daily_breakpoints_micro", replace	
		}
	if "`value'"=="value"{
		save "../output/sample_vw_`anything'_daily_breakpoints_micro", replace	
		}
		}
	if "`monthly'"=="monthly"{
		if "`value'"~="value"{
		save "../output/sample_ew_`anything'_monthly_breakpoints_micro", replace	
		}
	if "`value'"=="value"{
		save "../output/sample_vw_`anything'_monthly_breakpoints_micro", replace	
		}
		}
		

}


end

