clear
clear mata
clear matrix
set mem 5g
set more 1

cd "/Users/davidsraer/Dropbox/Speculative betas/revision2/progs"

			* 	THIS PROGRAM CREATES 40 BETA-SORTED PORTFOLIOS 	 *
			*	 TWO OPTIONS: MONTHLY VS. DAILY BETAS and VALUE	 * 
			*	 		vs. EQUAL-WEIGHTED RETURNS				 *
			*	COMPUTES FULL-SAMPLE BETAS OF PORTFOLIOS		 *
			

cap program drop construc_data_beta_split_nyse
program define   construc_data_beta_split_nyse
syntax [if] [in] [,VALue MONthly]

quietly{
	* starts from stock-level sample with monthly and daily betas and
	* future returns
	use "../output/stock_monthly_beta",replace
	* drop penny stocks (price<$5)
	drop if penny==1
	* drop microcaps (bottom 20% of size distribution using NYSE breakpoints)
	drop if microcap==1

	* BB is betas using NYSE stocks only
	* BB2 is betas using all stocks
	
	* definition with monthly option
	if "`monthly'"=="monthly"{	
	gen BB=beta_monthly if nyse==1
	gen BB2=beta_monthly
	}
	
	* definition with no monthly option
	if "`monthly'"~="monthly"{	
	gen BB=beta_daily if nyse==1
	gen BB2=beta_daily
	}
	
	* create 40 beta thresholds every month using NYSE stocks only
	forvalues i=2.5(2.5)97.5{
	local j=`i'*10
	cap drop p`j'
	egen p`j'=pctile(BB), p(`i') by(date)
	}
	* allocate stocks every month to these 40 bins	
	cap drop group
	gen group=1 if BB2<p25&BB2~=.
	forvalues i=5(2.5)97.5{
		local l=`i'*10
		local j=`l'-25
		replace group=(`i')/2.5 if BB2<p`l'&BB2>=p`j'&BB2~=.
		}
	replace group=40 if BB2>=p975&BB2~=.
	
	sort group date
	save "../output/local", replace
		
	
			********************************************************************	
			**** COMPUTING POST RANKING BETA OF 20 BETA-SORTED PORTFOLIOS *****
			********************************************************************
	
	* first when no-monthly option
	* this takes time since need daily observations for all the portfolios
	if "`monthly'"~="monthly"{	
	quietly{
	
		keep permno date group value
		quietly gen date2=year(date)*12+month(date)
		
		* define group (portfolio) as past month portfolio
		* this way, current returns are post-formation returns
		* i.e. 1 month after formation
		tsset permno date2
		quietly gen temp=L.group
		quietly drop group
		quietly gen group=temp
		cap drop temp
		quietly gen temp=L.value
		* we also use previous pre-formation value
		* when doing value weighting
		quietly drop value
		quietly gen value=temp
		quietly drop temp
		quietly drop date2
		quietly gen year=year(date)
		quietly gen month=month(date)
		keep year month group permno value
		
		* for a given year-month, dataset contains end-of-previous month beta group
		* and end-of-previous month value.
		* when we merge with daily returns, each daily return is attached to 
		* end-of-previous month beta portfolio
		
		sort permno year month
		save "../output/temp.dta", replace
			
		* first start with return data from 1980 to 1990 with factors
		* this dataset is created when we compute all the pre-ranking betas at stock
		*level
		use "../output/CRSP80_90.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		sort permno year month
		* merge with end-of-previous month portfolio group and end-of-previous month
		* value
		quietly merge m:1 permno year month using "../output/temp"
		keep if _m==3
		drop _m
		* collapse excess returns and market excess returns at portfolio-day level
		* option for value-weighting
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		* no option for value-weighting
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp2.dta", replace
		
		* repeat for 91-96
		use "../output/CRSP91_96.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		quietly keep if _m==3
		drop _m
		if "`value'"=="value"{	
		quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
		quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		quietly sort group date
		save "../output/temp3.dta", replace

		* repeat for 97-02
		use "../output/CRSP97_02.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		keep if _m==3
		drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp4.dta", replace
		
		* repeat for 03-10
		use "../output/CRSP03_10.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		quietly sort permno year month
		merge m:1 permno year month using "../output/temp"
		keep if _m==3
		drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp5.dta", replace

		* repeat for 11-12
		use "../output/CRSP11_12.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		quietly sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		quietly keep if _m==3
		quietly drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		save "../output/temp6.dta", replace

		* repeat for 13-14
		use "../output/CRSP13_14.dta", replace
		quietly gen year=year(date)
		quietly gen month=month(date)
		quietly sort permno year month
		quietly merge m:1 permno year month using "../output/temp"
		quietly keep if _m==3
		quietly drop _m
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 [w=value], by(date group)
		}
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5, by(date group)
		}
		sort group date
		
		* append to all the previous daily portfolio returns computed over 
		* different periods
		quietly append using "../output/temp6.dta"	
		quietly append using "../output/temp5.dta"	
		quietly append using "../output/temp4.dta"	
		quietly append using "../output/temp3.dta"
		quietly append using "../output/temp2.dta"
		
		*BETA_1 will be portfolio BETA over whole sample 	
		cap drop BETA_1
		quietly gen BETA_1=.
		*SIGMA_1 will be portfolio idio. volatility over whole sample 
		cap drop SIGMA_1
		quietly gen SIGMA_1=.
		
		sort group date		

		* loop over each of the portfolios
		quietly levelsof group, local(levels)
		foreach i of local levels {
			* use daily market model with 5 lags over 12/1982 to 12/2014
			reg ret_rf mktrf mktrf1 mktrf2 mktrf3 mktrf4 mktrf5 if group==`i' &year(date)*12+month(date)>=1981*12+12&year(date)<=2014
			replace BETA_1=_b[mktrf]+_b[mktrf1]+_b[mktrf2]+_b[mktrf3]+_b[mktrf4]+_b[mktrf5] if group==`i'
			replace SIGMA_1=e(rmse) if group==`i'
		}
		* keep only one observation per portfolio and only post-ranking beta and vol
		keep group BETA_1 SIGMA_1  
		bys group: keep if _n==1
		* erase temp files
		erase "../output/temp6.dta"	
		erase "../output/temp5.dta"	
		erase "../output/temp4.dta"	
		erase "../output/temp3.dta"
		erase "../output/temp2.dta"	
		erase "../output/temp.dta"
	}
	}
	
	* Computing now post-ranking betas on whole sample with monthly option
	if "`monthly'"=="monthly"{	
		quietly{
		* since this uses monthly return, no need to merge with return data
		* simply use current month excess return by stock
		keep permno date group value ret_rf mktrf
		quietly gen date2=year(date)*12+month(date)
		
		* define group (portfolio) as past month portfolio
		* this way, current returns are post-formation returns
		* i.e. 1 month after formation
		tsset permno date2
		quietly gen temp=L.group
		quietly drop group
		quietly gen group=temp
		* we also use previous pre-formation value
		* when doing value weighting
		cap drop temp
		quietly gen temp=L.value
		quietly drop value
		quietly gen value=temp
		quietly drop temp
		keep date2 date group permno value ret_rf mktrf
		* for a given year-month, dataset contains end-of-previous month beta group
		* and end-of-previous month value.
		* when we merge with daily returns, each daily return is attached to 
		* end-of-previous month beta portfolio
		
		* collapse excess returns at portfolio/month level, value-weighted option
		if "`value'"=="value"{	
			quietly collapse (mean) ret_rf mktrf  [w=value], by(date group)
		}
		* collapse excess returns at portfolio/month level, equal-weighted option
		if "`value'"~="value"{	
			quietly collapse (mean) ret_rf mktrf , by(date group)
		}
		*BETA_1 will be portfolio BETA over whole sample 			
		cap drop BETA_1
		quietly gen BETA_1=.
		*SIGMA_1 will be portfolio idio. volatility over whole sample 
		cap drop SIGMA_1
		quietly gen SIGMA_1=.
		sort group date		

		* loop over each of the portfolios
		quietly levelsof group, local(levels)
		foreach i of local levels {
		* use monthly market model with 5 lags over 12/1982 to 12/2014
		reg ret_rf mktrf  if group==`i' &year(date)*12+month(date)>=1981*12+12&year(date)<=2014
		replace BETA_1=_b[mktrf] if group==`i'
		replace SIGMA_1=e(rmse) if group==`i'
		}
		
		keep group BETA_1 SIGMA_1  
		bys group: keep if _n==1
	}
	}
	
	* merge dataset with post-ranking betas with stock-level dataset with
	* portfolio group
	sort group
	merge 1:m group using "../output/local"
	drop if _m==1
	drop _m
	
	* drop if portfolio group is not defined
	drop if group==.
	
	* save dataset with various options.
	sort group year month
	if "`monthly'"~="monthly"{
		if "`value'"~="value"{
		save "../output/sample_ew_40beta_daily_breakpoint", replace	
		}
	if "`value'"=="value"{
		save "../output/sample_vw_40beta_daily_breakpoint", replace	
		}
		}
	if "`monthly'"=="monthly"{
		if "`value'"~="value"{
		save "../output/sample_ew_40beta_monthly_breakpoint", replace	
		}
	if "`value'"=="value"{
		save "../output/sample_vw_40beta_monthly_breakpoint", replace	
		}
		}
		

}


end
