clear
clear mata
clear matrix
set more 1


*************************************************************************************************************************************************
**************************************************PROGRAMS TO RUN FOR THE ANALYSIS **************************************************************
*************************************************************************************************************************************************
*************************************************************************************************************************************************

cap program drop construc_stock_monthly
program define construc_stock_monthly
syntax [if] [in] 
	
	quietly{
	****start from CRSP monthly
	use "../source/CRSP_monthly_79_14.dta", clear
	drop if year(date)<1980
	ren date dateff	
	sort dateff
	****merge with monthly factors from WRDS
	merge m:1 dateff using  "../source/monthly_factor", keepusing(dateff rf mktrf)
	ren dateff date
	drop if _m==2
	drop _m
	***drop missing returns
	drop if ret==.
	
	***define dummies for nasdaq et nyse 
	sort permno date
	gen nasdaq=exchcd==3 if exchcd~=.
	gen nyse=exchcd==1 if exchcd~=.
	
	***drop micro-caps
	***At the end of each June from 1963 to 2005, we allocate NYSE, Amex, and (after 1972) NASDAQ stocks 
	****to three size groupsmicrocaps, small stocks, and big stocks. The breakpoints are the 20th and 50th percentiles 
	****of end-of-June market cap for NYSE stocks.
	
	gen size=abs(prc)*shrout 
		
	gen temp=size if nyse==1	
	***creates the breakpoints for the current months
	egen p20=pctile(temp),by(date) p(20)
	egen p50=pctile(temp),by(date) p(50)
	
	*** we drop microstocks, defined as stocks in the bottom 20percent of NYSE stocks
	gen microcap=size<p20 if size~=.
	
	***define small stocks
	gen small=size<p50 if size~=.
		
	*** penny stocks defined as stocks with a share price < 5 dollars today
	gen penny=abs(prc)<5 if abs(prc)~=.
		
	***turnover adjustment for nasdaq (from Gao and Ritter JFE 2010)
	sort date
	egen date3=group(date)
	tsset permno date3
	gen turnover=vol/shrout if nasdaq~=1
	replace turnover=vol/(2*shrout) if nasdaq==1&date<mdy(1,1,2001)
	replace turnover=vol/(1.8*shrout) if nasdaq==1&date>=mdy(1,1,2001)&date<=mdy(12,31,2001)
	replace turnover=vol/(1.6*shrout) if nasdaq==1&date<mdy(1,1,2004)&date>mdy(12,31,2001)
	replace turnover=vol/(shrout) if nasdaq==1&date>=mdy(1,1,2004)

	****define next month turnover
	gen turnover1=F1.turnover

	***1 month/ 3 months/ 6 month / 12 month FORWARD RETURNS 
	gen ret_rf=ret-rf
	gen ret1=(F1.ret)*100
	gen ret3=((1+F1.ret)*(1+F2.ret)*(1+F3.ret)-1)*100
	gen ret6=((1+F1.ret)*(1+F2.ret)*(1+F3.ret)*(1+F4.ret)*(1+F5.ret)*(1+F6.ret)-1)*100
	gen ret9=((1+F1.ret)*(1+F2.ret)*(1+F3.ret)*(1+F4.ret)*(1+F5.ret)*(1+F6.ret)*(1+F7.ret)*(1+F8.ret)*(1+F9.ret)-1)*100
	gen ret12=((1+F1.ret)*(1+F2.ret)*(1+F3.ret)*(1+F4.ret)*(1+F5.ret)*(1+F6.ret)*(1+F7.ret)*(1+F8.ret)*(1+F9.ret)*(1+F10.ret)*(1+F11.ret)*(1+F12.ret)-1)*100
	gen ret18=((1+F1.ret)*(1+F2.ret)*(1+F3.ret)*(1+F4.ret)*(1+F5.ret)*(1+F6.ret)*(1+F7.ret)*(1+F8.ret)*(1+F9.ret)*(1+F10.ret)*(1+F11.ret)*(1+F12.ret)*(1+F13.ret)*(1+F14.ret)*(1+F15.ret)*(1+F16.ret)*(1+F17.ret)*(1+F18.ret)-1)*100

	***1 month/ 3 months/ 6 month / 12 month FORWARD RETURNS in excess of the risk free rate
	gen ret_rf1=ret1- (F1.rf)*100
	gen ret_rf3=ret3-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)-1)*100
	gen ret_rf6=ret6-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)-1)*100
	gen ret_rf9=ret9-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)*(1+F7.rf)*(1+F8.rf)*(1+F9.rf)-1)*100
	gen ret_rf12=ret12-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)*(1+F7.rf)*(1+F8.rf)*(1+F9.rf)*(1+F10.rf)*(1+F11.rf)*(1+F12.rf)-1)*100
	gen ret_rf18=ret12-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)*(1+F7.rf)*(1+F8.rf)*(1+F9.rf)*(1+F10.rf)*(1+F11.rf)*(1+F12.rf)*(1+F13.rf)*(1+F14.rf)*(1+F15.rf)*(1+F16.rf)*(1+F17.rf)*(1+F18.rf)-1)*100
	
	
	***1 month/ 3 months/ 6 month / 12 month FORWARD RETURNS on the market in excess of the risk-free rate
	gen mkt=mktrf+rf
	gen mktrf_1=(F1.mktrf)*100
	gen mktrf_3=((1+F1.mkt)*(1+F2.mkt)*(1+F3.mkt)-1)*100-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)-1)*100
	gen mktrf_6=((1+F1.mkt)*(1+F2.mkt)*(1+F3.mkt)*(1+F4.mkt)*(1+F5.mkt)*(1+F6.mkt)-1)*100-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)-1)*100
	gen mktrf_9=((1+F1.mkt)*(1+F2.mkt)*(1+F3.mkt)*(1+F4.mkt)*(1+F5.mkt)*(1+F6.mkt)*(1+F7.mkt)*(1+F8.mkt)*(1+F9.mkt)-1)*100-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)*(1+F7.rf)*(1+F8.rf)*(1+F9.rf)-1)*100
	gen mktrf_12=((1+F1.mkt)*(1+F2.mkt)*(1+F3.mkt)*(1+F4.mkt)*(1+F5.mkt)*(1+F6.mkt)*(1+F7.mkt)*(1+F8.mkt)*(1+F9.mkt)*(1+F10.mkt)*(1+F11.mkt)*(1+F12.mkt)-1)*100-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)*(1+F7.rf)*(1+F8.rf)*(1+F9.rf)*(1+F10.rf)*(1+F11.rf)*(1+F12.rf)-1)*100
	gen mktrf_18=((1+F1.mkt)*(1+F2.mkt)*(1+F3.mkt)*(1+F4.mkt)*(1+F5.mkt)*(1+F6.mkt)*(1+F7.mkt)*(1+F8.mkt)*(1+F9.mkt)*(1+F10.mkt)*(1+F11.mkt)*(1+F12.mkt)*(1+F13.mkt)*(1+F14.mkt)*(1+F15.mkt)*(1+F16.mkt)*(1+F17.mkt)*(1+F18.mkt)-1)*100-((1+F1.rf)*(1+F2.rf)*(1+F3.rf)*(1+F4.rf)*(1+F5.rf)*(1+F6.rf)*(1+F7.rf)*(1+F8.rf)*(1+F9.rf)*(1+F10.rf)*(1+F11.rf)*(1+F12.rf)*(1+F13.rf)*(1+F13.rf)*(1+F15.rf)*(1+F16.rf)*(1+F17.rf)*(1+F18.rf)-1)*100
	
	***only keep relevant variables.
	keep nasdaq permno date nyse ret* mktrf* mkt  prc shrout  turnover* penny small microcap
	gen date2=year(date)*12+month(date)
	sort permno date2 
	save "../output/local", replace
	
	use "../output/local", replace
	*** merging with current months daily beta
	merge 1:1 permno date2 using "../output/betas_total", keepusing(permno date2 beta sigma)
	drop if _m==2
	drop _m
	quietly compress
	ren beta beta_daily
	ren sigma sigma_daily
	*** merging with current months monthly beta
	sort permno date2 
	merge 1:1 permno date2 using "../output/betas_total_monthly", keepusing(permno date2 beta sigma)
	drop if _m==2
	drop _m
	quietly compress
	ren beta beta_monthly
	ren sigma sigma_monthly
	drop date2
	egen date2=group(date)
	***compute market cap for current month
	cap drop value
	gen value=abs(prc)*shrout
	cap drop year month
	gen year=year(date)
	gen month=month(date)
	sort permno year month
	save "../output/temp",replace

	
	***merge with IBES data from Jialin Yu to get stock-level disagreement.
	use "../source/merged_updated.dta", clear
	keep permno year month stdevwin meanestwin
	sort permno year month
	merge 1:1 permno year month using "../output/temp"
	drop if _m==1
	drop _m
	
	**** turnover has severe outliers, so we windsorize upper tail at 5% level.
	sum turnover, d
	replace turnover=r(p95) if turnover~=.&turnover>r(p95)
	
	sort permno date
	***stock_monthly_beta is stock-level data before we collapse
	save "../output/stock_monthly_beta",replace
	}
	
	end
