
* cd
* input your directory here.

				**************************************************
				* 		TABLE 3: SML CONCAVITY AND DISAGREEMENT	 *
				* 		REPLICATE PANEL A						 *
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use  ../source/20_beta_sorted_portfolios, replace	

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")


				**************************************************
				* 		TABLE 5: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				**************************************************

*** first, value weighted with median beta/sigma^2 as breakpoint
use ../source/40_beta_portfolios_spec_nonspec, replace
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median daily volatility of stocks in portfolio
gen lsigma=ln(sigma_daily)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table3_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table3_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))
