clear
clear mata
clear matrix
set mem 5g
set more 1


*** program to standardize time-series variables.

cap program drop standardize
program define standardize
cap drop m
egen m=mean(`1')
cap drop s
egen s=sd(`1')
replace `1'=(`1'-m)/s
drop m s
end

		* 	THIS PROGRAM GENERATES THE TABLES AND FIGURES	 *
		*	FOR SPECULATIVE BETAS							 * 
		*	(HONG AND SRAER 2015)							 *
		

		
				**************************************************
				*	Figure: AGGREGATE DISAGREEMENT TIME SERIES	 *	
				**************************************************
use ../output/time_series, replace

label var aggregate_disp_daily "Aggregate Disagreement"
label var date "Date"
format date  %tdCCYY
line aggregate_disp_daily date
gr export "../figures/time_series1.pdf", replace 
				
				
				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				**************************************************

* First value-weighted

* construct dataset with 20-beta sorted porftolios
* use value option (and no monthly option --> daily betas)
do construc_data_beta_all_breakpoints
construc_beta_all_breakpoint, value

use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* define slope1 and slope0
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regression
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	quietly cap  reg ret_rf12 BETA_1 if date==`l' 
	* slope 1 is slope of SML in month `l'
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope 0 is intercept of SML in month `l'
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	
*only keep one observations of slope and intercept per year month
collapse (max) slope1 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope and intercept on aggregate disp. and other time-series variables
quietly{
forvalues i=0(1)1{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* value-weighted panel of the Table.
estout A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table0.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

*now equal weighted panel

* construct dataset with 20-beta sorted porftolios
* use no value option (and no monthly option --> daily betas and equal weighted)

do construc_data_beta_all_breakpoints
construc_beta_all_breakpoint 

* use construced dataset
use "../output/sample_ew_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1, by(group date year month)

* define slope1 and slope0
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.
* loop over months  -- cross-sectional regression
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	quietly cap  reg ret_rf12 BETA_1 if date==`l' 
	* slope 1 is slope of SML in month `l'
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope 0 is intercept in month `l'
	quietly cap  replace slope0=_b[_cons] if date==`l'

}	

*only keep one observations of slope and intercept per year month
collapse (max) slope1 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope and intercept on aggregate disp. and other time-series variables
quietly{
forvalues i=0(1)1{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
*equal-weighted panel of Table
estout A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table0_ew.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

				
				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

* equal-weighted panel
* use equal-weighted sample of beta-sorted portfolios
use "../output/sample_ew_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1, by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Equal-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1_ew.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))


	
				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				**************************************************

*** first, value weighted with median beta/sigma^2 as breakpoint
do construc_data1_breakpoints
construc_data1_breakpoints 50, value
* use 40 value-weighted sample of beta-sorted portfolios for spec and non-spec stocks
use "../output/sample_vw_50_daily_breakpoints", replace
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we use the median daily-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_daily (mean) ret_rf* SIGMA_1 BETA_1 [w=value] ,by(year month date group spec)
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median daily volatility of stocks in portfolio
gen lsigma=ln(sigma_daily)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table3_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table3_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))

				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				*					EQUAL-WEIGHTED				 *
				**************************************************

*** equal-weighted portfolios with median beta/sigma^2 as breakpoint
do construc_data1_breakpoints
construc_data1_breakpoints 50
* use 40 equal-weighted sample of beta-sorted portfolios for spec and non-spec stocks
use "../output/sample_ew_50_daily_breakpoints", replace
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we use the median daily-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_daily (mean) ret_rf* SIGMA_1 BETA_1,by(year month date group spec)
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median daily volatility of stocks in portfolio
gen lsigma=ln(sigma_daily)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table4_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table4_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))

				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				*		 VARIOUS RETURNS HORIZONS				 *
				**************************************************

* we use value-weighted sample, with median for spec-stocks and daily returns
use "../output/sample_vw_50_daily_breakpoints", replace
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we use the median daily-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_daily (mean) ret_rf* SIGMA_1 BETA_1 [w=value] ,by(year month date group spec)
* define lsigma as ln of median volatility using daily returns
gen lsigma=ln(sigma_daily)

* loop over horizons over which we will run regressions
foreach x in 1 3 6 18{
* define slope1, slope2 and slope0 for each horizon
	cap drop slope1_`x'
	gen slope1_`x'=.
	cap drop slope2_`x'
	gen slope2_`x'=.
	cap drop slope0_`x'=.
	gen slope0_`x'=.
		
	* loop over month -- cross-sectional regressions
	quietly levelsof date, local(levels)
	foreach l of local levels {
	* loop over speculative and non-speculative portfolios 
		forvalues p=0(1)1{
		* regress portfolio `x' months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
			quietly cap  reg ret_rf`x' BETA_1 lsigma if date==`l' &spec==`p' 
			quietly cap  replace slope1_`x'=_b[BETA_1] if date==`l'&spec==`p'
			quietly cap  replace slope2_`x'=_b[lsigma] if date==`l'&spec==`p'
			quietly cap  replace slope0_`x'=_b[_cons] if date==`l'&spec==`p'
		}
	}	
}
* keep only 1 observation per month for spec and non-spec portfolios
collapse (max) slope1* slope2* slope0*, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D

* keep if non-missing slope, inflation and disagreement variable
keep if slope1_1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables for these various horizons

quietly{
foreach x in 1 3 6 18{
	forvalues j=0(1)1{
		forvalues i=0(1)2{
			newey slope`i'_`x' aggregate_disp_daily if spec==`j', lag(`x') force
			estimates store A1_`j'_`i'_`x'
			newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' if spec==`j', lag(`x') force
			estimates store A2_`j'_`i'_`x'
			newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' dp inflation  if spec==`j', lag(`x') force
			estimates store A3_`j'_`i'_`x'
			newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' dp inflation TED  if spec==`j', lag(`x') force
			estimates store A4_`j'_`i'_`x'
		}
	}
}
}

* labels
foreach x in 1 3 6 18{
label var mktrf_`x' "$\text{R}_{m,t}^{(`x')}$"
label var hml_`x' "$\text{HML}_{t}^{(`x')}$"
label var smb_`x' "$\text{SMB}_{t}^{(`x')}$"
label var umd_`x' "$\text{UMD}_{t}^{(`x')}$"
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* tables
foreach x in 1 3 6 18{
estout A1_1_1_`x' A2_1_1_`x' A3_1_1_`x' A4_1_1_`x' A1_1_2_`x' A2_1_2_`x' A3_1_2_`x' A4_1_2_`x'  A1_1_0_`x' A2_1_0_`x' A3_1_0_`x' A4_1_0_`x' using ../tables/hong_table5_1_`x'.tex, keep(aggregate_disp_daily) replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1_`x' A2_0_1_`x' A3_0_1_`x' A4_0_1_`x'  A1_0_2_`x' A2_0_2_`x' A3_0_2_`x' A4_0_2_`x'  A1_0_0_`x' A2_0_0_`x' A3_0_0_`x' A4_0_0_`x' using ../tables/hong_table5_2_`x'.tex, keep(aggregate_disp_daily) replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))
}

				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				*		USING MONTHLY BETAS
				**************************************************

* value weighted with median beta/sigma^2 as breakpoint and monthly betas
do construc_data1_breakpoints
construc_data1_breakpoints 50, value monthly
* use 40 value-weighted sample of beta-sorted portfolios for spec and non-spec stocks
* with monthly betas used in portfolio construction
use "../output/sample_vw_50_monthly_breakpoints", replace
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we use the median monthly-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_monthly (mean) ret_rf* SIGMA_1 BETA_1 [w=value] ,by(year month date group spec)
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median monthly volatility of stocks in portfolio
gen lsigma=ln(sigma_monthly)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
* note that we use aggregate_disp_monthly for consistency
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_monthly if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_monthly "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table6_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table6_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))

				**************************************************
				* 		FIGURE: SENSITIVITY TO DIFFERENT		 *
				* 		CUTS FOR DEFINING SPECULATIVE STOCKS	 *
				* 			COLUMN (3) SPECIFICATION
				**************************************************
				
* value weighted with quintile `i' in beta/sigma^2 as breakpoint and daily betas			
do construc_data1_breakpoints
forvalues i=30(5)70{
construc_data1_breakpoints `i', value
	}

* we will store regression coefficients into dataset coeffs
clear
gen x=.
save ../output/coeffs, replace
* this figure will use the specification from column (3) -- control for 
* Rm, HML, SMB, UMD, DP and Inflation

forvalues r=30(5)70{
	* start with constructed dataset -- value-weighted, daily betas and cutoff `r'
	use "../output/sample_vw_`r'_daily_breakpoints", replace
	drop if group==.
	* collapse returns at the portfolio level, using current month value weight
	* note that BETA_1 is post-ranking beta, so constant by group.
	* we use the median monthly-volatility to characterize the volatility of stocks
	* in each portfolio
	collapse (median) sigma_daily (mean) ret_rf* BETA_1 [w=value] ,by(year month date group spec)
	* define slope1, slope2 and slope0
	cap drop slope1
	gen slope1=.
	cap drop slope2
	gen slope2=.
	cap drop slope0
	gen slope0=.
	* define lsigma: ln of median daily volatility of stocks in portfolio
	gen lsigma=ln(sigma_daily)
	* loop over months -- cross sectional regressions
	quietly levelsof date, local(levels)
	foreach l of local levels {
		forvalues p=0(1)1{
			* regress portfolio 12 months forward return on post-ranking portfolio beta
			* and ln of sigma, separately for speculative and non-speculative portfolios
			quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
			quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
			quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
			quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
		}
	}	
	* keep only 1 observation per month
	collapse (max) slope1 slope2 slope0, by(date year month spec)
	drop if spec==.
	* merge with time-series variables
	sort year month
	merge m:1 year month using "../output/time_series"
	drop if _m==2
	drop _m

	sort year month	
	cap drop D
	egen D=group(year month)
	tsset spec D
	* keep if non-missing slope, inflation and disagreement variable
	keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
	* standardize time-series variable over final sample
	standardize aggregate_disp_daily
	standardize dp 
	standardize inflation
	standardize TED
	* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
	* and other time-series variables
	* for each of these cutoffs
	quietly{
	forvalues j=0(1)1{
		forvalues i=0(1)2{
			newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
			estimates store A1_`j'_`i'
			newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
			estimates store A2_`j'_`i'
			newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
			estimates store A3_`j'_`i'
			newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
			estimates store A4_`j'_`i'
			}
		}
	}
	* store the results in tables with cutoff `r'
	estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table7_1_`r'.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
	estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table7_2_`r'.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))
	* define coeff and s.e. for interaction of aggregate_disp and beta
	* for speculative and non-speculative stocks
	gen XX1=.
	gen XX2=.
	gen YY1=.
	gen YY2=.
	* for speculative stocks --> retrieve slope of SML and s.e. 
	newey slope1 aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==1, lag(11) force
	replace XX1=_b[aggregate_disp_daily]
	replace XX2=_se[aggregate_disp_daily]
	* for non speculative stocks --> retrieve slope of SML and s.e. 
	newey slope1 aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==0, lag(11) force
	replace YY1=_b[aggregate_disp_daily]
	replace YY2=_se[aggregate_disp_daily]
	* keep one observation corresponding to cutoff `r'
	collapse (max) XX1 XX2 YY1 YY2
	* define cut as cutoff used `r'
	gen cut=`r'
	* append to previously found coefficients with previous cutoffs
	append using ../output/coeffs
	* and save
	save ../output/coeffs,replace
}
* generate figure

label var XX1 "Point estimates"
label var YY1 "Point estimates"
* confidence interval around estimate
gen XX1_down=XX1-1.96*XX2
gen XX1_up=XX1+1.96*XX2
gen YY1_down=YY1-1.96*YY2
gen YY1_up=YY1+1.96*YY2
*label
label var cut "percentile used to define speculative stocks"
* plots coefficients with cutoff used
twoway (line XX1 cut,ylabel(-20(5)10))(line XX1_up cut, clstyle(dot) clwidth(thick))(line XX1_down cut, clstyle(dot)  clwidth(thick)), name(graph1, replace) legend(rows(1) order(1 "Point estimate" 2 "95% CI")) ti("Speculative Stocks")
twoway (line YY1 cut,ylabel(-20(5)10))(line YY1_up cut, clstyle(dot) clwidth(thick))(line YY1_down cut, clstyle(dot)  clwidth(thick)), name(graph2, replace) legend(rows(1) order(1 "Point estimate" 2 "95% CI")) ti("Non-Speculative Stocks")
graph combine graph1 graph2
gr export "../figures/cut_robust.pdf", replace 


				**************************************************
				* 		FIGURE: SENSITIVITY TO DIFFERENT		 *
				* 		CUTS FOR DEFINING SPECULATIVE STOCKS	 *
				* 			COLUMN (2) SPECIFICATION
				**************************************************
				
* value weighted with quintile `i' in beta/sigma^2 as breakpoint and daily betas			
do construc_data1_breakpoints
forvalues i=30(5)70{
construc_data1_breakpoints `i', value
	}

* we will store regression coefficients into dataset coeffs
clear
gen x=.
save ../output/coeffs, replace
* this figure will use the specification from column (2) -- control for 
* Rm, HML, SMB, UMD

forvalues r=30(5)70{
	* start with constructed dataset -- value-weighted, daily betas and cutoff `r'
	use "../output/sample_vw_`r'_daily_breakpoints", replace
	drop if group==.
	* collapse returns at the portfolio level, using current month value weight
	* note that BETA_1 is post-ranking beta, so constant by group.
	* we use the median monthly-volatility to characterize the volatility of stocks
	* in each portfolio
	collapse (median) sigma_daily (mean) ret_rf* BETA_1 [w=value] ,by(year month date group spec)
	* define slope1, slope2 and slope0
	cap drop slope1
	gen slope1=.
	cap drop slope2
	gen slope2=.
	cap drop slope0
	gen slope0=.
	* define lsigma: ln of median daily volatility of stocks in portfolio
	gen lsigma=ln(sigma_daily)
	* loop over months -- cross sectional regressions
	quietly levelsof date, local(levels)
	foreach l of local levels {
		forvalues p=0(1)1{
			* regress portfolio 12 months forward return on post-ranking portfolio beta
			* and ln of sigma, separately for speculative and non-speculative portfolios
			quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
			quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
			quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
			quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
		}
	}	
	* keep only 1 observation per month
	collapse (max) slope1 slope2 slope0, by(date year month spec)
	drop if spec==.
	* merge with time-series variables
	sort year month
	merge m:1 year month using "../output/time_series"
	drop if _m==2
	drop _m

	sort year month	
	cap drop D
	egen D=group(year month)
	tsset spec D
	* keep if non-missing slope, inflation and disagreement variable
	keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
	* standardize time-series variable over final sample
	standardize aggregate_disp_daily
	standardize dp 
	standardize inflation
	standardize TED
	* define coeff and s.e. for interaction of aggregate_disp and beta
	* for speculative and non-speculative stocks
	gen XX1=.
	gen XX2=.
	gen YY1=.
	gen YY2=.
	* for speculative stocks --> retrieve slope of SML and s.e. 
	newey slope1 aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12  if spec==1, lag(11) force
	replace XX1=_b[aggregate_disp_daily]
	replace XX2=_se[aggregate_disp_daily]
	* for non speculative stocks --> retrieve slope of SML and s.e. 
	newey slope1 aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12  if spec==0, lag(11) force
	replace YY1=_b[aggregate_disp_daily]
	replace YY2=_se[aggregate_disp_daily]
	* keep one observation corresponding to cutoff `r'
	collapse (max) XX1 XX2 YY1 YY2
	* define cut as cutoff used `r'
	gen cut=`r'
	* append to previously found coefficients with previous cutoffs
	append using ../output/coeffs
	* and save
	save ../output/coeffs,replace
}
* generate figure

label var XX1 "Point estimates"
label var YY1 "Point estimates"
* confidence interval around estimate
gen XX1_down=XX1-1.96*XX2
gen XX1_up=XX1+1.96*XX2
gen YY1_down=YY1-1.96*YY2
gen YY1_up=YY1+1.96*YY2
*label
label var cut "percentile used to define speculative stocks"
* plots coefficients with cutoff used
twoway (line XX1 cut,ylabel(-20(5)10))(line XX1_up cut, clstyle(dot) clwidth(thick))(line XX1_down cut, clstyle(dot)  clwidth(thick)), name(graph1, replace) legend(rows(1) order(1 "Point estimate" 2 "95% CI")) ti("Speculative Stocks")
twoway (line YY1 cut,ylabel(-20(5)10))(line YY1_up cut, clstyle(dot) clwidth(thick))(line YY1_down cut, clstyle(dot)  clwidth(thick)), name(graph2, replace) legend(rows(1) order(1 "Point estimate" 2 "95% CI")) ti("Non-Speculative Stocks")
graph combine graph1 graph2
gr export "../figures/cut_robust2.pdf", replace 

	
				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				* 				INCLUDING MICROCAPS				 *
				**************************************************

* value weighted with median beta/sigma^2 as breakpoint including microcaps
do construc_data1_breakpoints_micro
construc_data1_breakpoints_micro 50, value
* use 40 value-weighted sample of beta-sorted portfolios for spec and non-spec stocks
* including microcaps
use "../output/sample_vw_50_daily_breakpoints_micro", replace
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we use the median daily-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_daily (mean) ret_rf* BETA_1 [w=value] ,by(year month date group spec)
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median daily volatility of stocks in portfolio
gen lsigma=ln(sigma_daily)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table8_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table8_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))


				**************************************************
				* 		TABLE: SML SLOPE FOR 					 *
				*			 LOW AND HIGH BETA STOCKS			 *
				**************************************************

* construct 40 beta-sorted portfolios, value weighted, using NYSE breakpoints				
do construc_data_beta_split_nyse
construc_data_beta_split_nyse, value

* use resulting dataset
use "../output/sample_vw_40beta_daily_breakpoint",replace
* drop if no group attribution
drop if group==.
* define speculative stocks as top 20 beta-sorted portfolios
gen spec=group>=21 if group~=.

* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value] ,by(year month date group spec)

* define slope1 and slope0
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* for high and low beta portfolios separately
		quietly cap  reg ret_rf12 BETA_1  if date==`l' &spec==`p'
		* slope1 is SML slope for high/low beta portfolios
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		* slope0 is intercept
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* only keep one observation per month
collapse (max) slope1  slope0, by(date year month spec)
drop if spec==.
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables for high and low beta portfolios separately

quietly{
	forvalues j=0(1)1{
		forvalues i=0(1)1{
			newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
			estimates store A1_`j'_`i'
			newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
			estimates store A2_`j'_`i'
			newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
			estimates store A3_`j'_`i'
			newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
			estimates store A4_`j'_`i'
		}
	}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
*tables -- two panels: high and low beta portfolios
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table9_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table9_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))
				
				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				* 		OTHER MEASURES OF DISAGREEMENT			 *
				**************************************************

* use value-weighted portfolios
use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable for this sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
standardize spf
gen top_down=L.topdown_disag1
standardize top_down

* loop over different measure of disagreement
foreach x in aggregate_disp_daily2 aggregate_disp_daily3 spf top_down{
quietly{
	forvalues i=0(1)2{
			newey slope`i' `x', lag(11) force
			estimates store A1_`i'_`x'
			newey slope`i' `x'  mktrf_12 hml_12 smb_12 umd_12, lag(11) force
			estimates store A2_`i'_`x'
			newey slope`i' `x' mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
			estimates store A3_`i'_`x'
			newey slope`i' `x' mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
			estimates store A4_`i'_`x'
	}
	}
}
* labels
label var aggregate_disp_daily2 "$\text{Agg. Disp.}_{t-1}$"
label var aggregate_disp_daily3 "$\text{Agg. Disp.}_{t-1}$"
label var spf "$\text{Agg. Disp.}_{t-1}$"
label var top_down "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* tables
foreach x in aggregate_disp_daily2 aggregate_disp_daily3 spf top_down{
	estout A1_2_`x' A2_2_`x' A3_2_`x' A4_2_`x' A1_1_`x' A2_1_`x' A3_1_`x' A4_1_`x'  A1_0_`x' A2_0_`x' A3_0_`x' A4_0_`x' using ../tables/hong_table1_`x'.tex, keep(`x') replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
}

				**************************************************
				* 	TABLE: SHORTING, TURNOVER AND DISAGREEMENT	 *
				**************************************************

* use 20 value-weighted beta-sorted portfolios using daily data constructed 
* above
use "../output/sample_vw_all_beta_daily_breakpoint", replace	
drop if group==.
* collapse characteristics at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we take the median characteristics for each portfolio
collapse (median) value stdevwin sr turnover (mean) BETA_1 [w=value],by(group date year month)
* define lsize as ln median market cap for stocks in portfolio in current month
gen lsize=ln(value)
* define lstdevwin as ln median stock-dispersion for stocks in portfolio in current month
gen lstdevwin=ln(stdevwin)
foreach x in sr lstdevwin turnover{
* define all the slope of the cross-sectional monthly regression
* for each of the outcome variable
cap drop slope1_1_`x'
gen slope1_1_`x'=.
cap drop slope0_1_`x'=.
gen slope0_1_`x'=.
cap drop slope2_2_`x'
gen slope2_2_`x'=.
cap drop slope1_2_`x'=.
gen slope1_2_`x'=.
cap drop slope0_2_`x'=.
gen slope0_2_`x'=.
quietly levelsof date, local(levels)
foreach l of local levels {
	* cross-sectional regression: portfolio characteristics on portfolio beta
	quietly cap  reg `x' BETA_1 if date==`l' 
	quietly cap  replace slope1_1_`x'=_b[BETA_1] if date==`l'
	quietly cap  replace slope0_1_`x'=_b[_cons] if date==`l'
	* cross-sectional regression: portfolio characteristics on portfolio beta controling for
	* median size of stocks in portfolio.
	quietly cap  reg `x' BETA_1 lsize if date==`l' 
	quietly cap  replace slope2_2_`x'=_b[lsize] if date==`l'
	quietly cap  replace slope1_2_`x'=_b[BETA_1] if date==`l'
	quietly cap  replace slope0_2_`x'=_b[_cons] if date==`l'
	}	
}
* only keep one observation per month
collapse (max) slope*, by(date year month)
* merge with time-series variable
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m


forvalues i=1(1)2{
	forvalues j=0(1)2{
		foreach x in sr lstdevwin turnover{ 
			* reg these slopes on constant and aggregate disp	
			quietly cap reg slope`j'_`i'_`x' aggregate_disp_daily
			cap estimates store A_`i'_`j'_`x'
		}
	}
}
* label
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
*tables
foreach x in sr lstdevwin turnover{ 	
	estout A_1_1_`x' A_1_0_`x' A_2_1_`x' A_2_2_`x' A_2_0_`x' using ../tables/hong_table11_`x'.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
}


				******************************************************
				* 	FIGURE: AVERAGE RETURN OF BETA-SORTED PORTFOLIOS *
				* 	FOR HIGH AND LOW DISAGREEMENT MONTHS			 *
				******************************************************
				
* use stock sample of 20-beta-sorted portfolios, using daily beta and value-weighted returns	
use "../output/sample_vw_all_beta_daily_breakpoint", replace			
drop if group==.
* collapse future excess-returns at portfolio/day level
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)
sort year month
* merge with time-series characteristics
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m
* keep months where aggregate disagreement is defined
drop if aggregate_disp_daily==.
* create quartile of aggregate disagreement
egen TT=xtile(aggregate_disp_daily), nq(4)
* indicator variable for first-observation within portfolio/quartile of disagreement
bys group TT: gen ind=_n==1

foreach x in 3 6 12 18{
	cap drop m`x'
	* average `x' month forward return of portfolios for each quartile of disagreement 	
	egen m`x'=mean(ret_rf`x'),by(group TT)
	* labels
	label var m`x' "`x' month forward excess returns"		
	label var BETA "Portfolio post-ranking Beta"		
	* figure
	twoway (scatter m`x' BETA if TT==1, mcolor(blue)) (scatter m`x' BETA if TT==4, mcolor(red)), legend(rows(1) order(1 "Low disagreement" 2 "High disagreement"))
	gr export "../figures/ret`x'_vw.pdf", replace
	gr export "../figures/ret`x'_vw.png", replace
}
				
				******************************************************
				* 	FIGURE: AVERAGE RETURN OF BETA-SORTED PORTFOLIOS *
				* 	FOR HIGH AND LOW DISAGREEMENT MONTHS			 *
				******************************************************
				
* use stock sample of 20-beta-sorted portfolios, using daily beta and value-weighted returns	
* for speculative and non-spec stocks using the median beta/sigma^2 as breakpoint
use "../output/sample_vw_50_daily_breakpoints", replace
drop if group==.
* collapse future excess-returns at portfolio/day level
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1, by(group date year month spec)
sort year month
* merge with time-series characteristics
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m
* keep months where aggregate disagreement is defined
drop if aggregate_disp_daily==.
* create quartile of aggregate disagreement
egen TT=xtile(aggregate_disp_daily), nq(4)
* indicator variable for first-observation within portfolio/quartile of disagreement	
bys group TT: gen ind=_n==1

* m12 is average 12 months forward returns for beta-sorted porftolios of speculative
* and non-speculative stocks
cap drop m12
egen m12=mean(ret_rf12),by(group TT)
* labels
label var m12 "12 month forward excess returns"		
label var BETA "Portfolio post-ranking Beta"		

* first graph for speculative stocks
twoway (scatter m12 BETA if TT==1&spec==1, mcolor(blue)) (scatter m12 BETA if TT==4&spec==1, mcolor(red)), legend(rows(1) order(1 "Low disagreement" 2 "High disagreement"))
gr export "../figures/ret12_vw_spec.pdf", replace
gr export "../figures/ret12_vw_spec.png", replace
* second graph for non speculative stocks
twoway (scatter m12 BETA if TT==1&spec==0, mcolor(blue)) (scatter m12 BETA if TT==4&spec==0, mcolor(red)), legend(rows(1) order(1 "Low disagreement" 2 "High disagreement"))
gr export "../figures/ret12_vw_nospec.pdf", replace
gr export "../figures/ret12_vw_nospec.png", replace

	
	
	
				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 			USING CASH FLOW BETA				 *	
				**************************************************


* program to construct 20 cash-flow  beta sorted portfolios
* as well as  portfolios of stocks that are first assigned in two groups
* based on cash-flow beta/volatility
* and then sorted into 20 cash-flow beta sorted portfolios

do construc_beta_all_breakpoint_CV				
				
* use stock sample of 20-cash-flow beta-sorted portfolios,
* using cash flow monthly beta and value-weighted returns	
	
use "../output/sample_vw_all_beta_monthly_breakpoint_CV", replace	
drop if group==.
* collapse future excess-returns at portfolio/day level
* note that BETA_CF is post-ranking cash-flow beta, so constant by group.
collapse (mean) ret_rf* BETA_CF BETA_DR [w=value], by(group date year month)
* define slope1 , slope0
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.
* cross-sectional regression of stock returns on portfolio cash flow beta
quietly levelsof date, local(levels)
foreach l of local levels {
quietly cap  reg ret_rf12 BETA_CF if date==`l' 
quietly cap  replace slope1=_b[BETA_CF] if date==`l'
quietly cap  replace slope0=_b[_cons] if date==`l'

}	

* only keep 1 observation per month
collapse (max) slope1 slope0,by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D

keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
standardize aggregate_disp_CF
standardize dp 
standardize inflation
standardize TED
quietly{
forvalues i=0(1)1{
newey slope`i' aggregate_disp_CF, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}

label var aggregate_disp_CF "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

estout A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table0_CV.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")



				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				* 			USING CASH FLOW BETA				 *	
				**************************************************
* use stock sample of 20-cash-flow beta-sorted portfolios,
* using cash flow monthly beta and value-weighted returns	
use "../output/sample_vw_all_beta_monthly_breakpoint_CV", replace	
drop if group==.
collapse (mean) ret_rf* BETA_CF BETA_DR [w=value], by(group date year month)
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.
cap drop slope2=.
gen slope2=.

gen BETA2=BETA_CF^2
quietly levelsof date, local(levels)
foreach l of local levels {
quietly cap  reg ret_rf12 BETA_CF BETA2 if date==`l' 
quietly cap  replace slope2=_b[BETA2] if date==`l'
quietly cap  replace slope1=_b[BETA_CF] if date==`l'
quietly cap  replace slope0=_b[_cons] if date==`l'

}	

* only keep one observation per month
collapse (max) slope2 slope1 slope0,by(year month)
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D

keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
	quietly{
	forvalues i=0(1)2{
		newey slope`i' aggregate_disp_CF, lag(11) force
		estimates store A1_`i'
		newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12, lag(11) force
		estimates store A2_`i'
		newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
		estimates store A3_`i'
		newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
		estimates store A4_`i'
	}
}
* labels
label var aggregate_disp_CF "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1_CV.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))



				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				*		USING CASH FLOW BETAS
				**************************************************

* use 40 value-weighted sample of cash-flow beta-sorted portfolios for spec and non-spec stocks
* with cash-flow betas used in portfolio construction
use "../output/sample_vw_50_monthly_breakpoints_CV", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking CASH FLOW beta, so constant by group.
* we use the median monthly-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_monthly (mean) ret_rf* BETA_CF BETA_DR [w=value] ,by(year month date group spec)
ren BETA_CF BETA_1
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median monthly volatility of stocks in portfolio
gen lsigma=ln(sigma_monthly)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
* note that we use aggregate_disp_monthly for consistency
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_CF if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_CF mktrf_12 hml_12 smb_12 umd_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_CF "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table3_1_CV.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table3_2_CV.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))


				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				*		MONTHLY BETA
				**************************************************

* First value-weighted

* construct dataset with 20-beta sorted porftolios
* use value option (and no monthly option --> daily betas)
do construc_data_beta_all_breakpoints
construc_beta_all_breakpoint, monthly value

use "../output/sample_vw_all_beta_monthly_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* define slope1 and slope0
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regression
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	quietly cap  reg ret_rf12 BETA_1 if date==`l' 
	* slope 1 is slope of SML in month `l'
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope 0 is intercept of SML in month `l'
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	
*only keep one observations of slope and intercept per year month
collapse (max) slope1 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope and intercept on aggregate disp. and other time-series variables
quietly{
forvalues i=0(1)1{
newey slope`i' aggregate_disp_monthly, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
* labels
label var aggregate_disp_monthly "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* value-weighted panel of the Table.
estout A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table_robust0.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

*now equal weighted panel

* construct dataset with 20-beta sorted porftolios
* use no value option (and no monthly option --> daily betas and equal weighted)

do construc_data_beta_all_breakpoints
construc_beta_all_breakpoint, monthly

* use construced dataset
use "../output/sample_ew_all_beta_monthly_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1, by(group date year month)

* define slope1 and slope0
cap drop slope1
gen slope1=.
cap drop slope0=.
gen slope0=.
* loop over months  -- cross-sectional regression
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	quietly cap  reg ret_rf12 BETA_1 if date==`l' 
	* slope 1 is slope of SML in month `l'
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope 0 is intercept in month `l'
	quietly cap  replace slope0=_b[_cons] if date==`l'

}	

*only keep one observations of slope and intercept per year month
collapse (max) slope1 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope and intercept on aggregate disp. and other time-series variables
quietly{
forvalues i=0(1)1{
newey slope`i' aggregate_disp_monthly, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_monthly "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
*equal-weighted panel of Table
estout A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table_robust0_ew.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

				
				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				*				MONTHLY BETAS					 *
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use "../output/sample_vw_all_beta_monthly_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_monthly, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_monthly "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table_robust1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

* equal-weighted panel
* use equal-weighted sample of beta-sorted portfolios
use "../output/sample_ew_all_beta_monthly_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1, by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_monthly, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_monthly mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_monthly "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Equal-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table_robust1_ew.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))


				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				*			DIFFERENT HORIZONS					 *
				**************************************************

* start from stock-level sample of 20-beta sorted portfolios with NYSE breakpoints
use "../output/sample_vw_all_beta_daily_breakpoint", replace	
drop if group==.
* collpase returns at portfolio level
* BETA_1 is post ranking beta, so constant across group
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)
		
* run cross-sectional regression for each horizon		
foreach x in 1 3 6 12 18{
	cap drop slope1_`x'
	gen slope1_`x'=.
	cap drop slope0_`x'=.
	gen slope0_`x'=.
	quietly levelsof date, local(levels)
	foreach l of local levels {
		quietly cap  reg ret_rf`x' BETA_1 if date==`l' 
		quietly cap  replace slope1_`x'=_b[BETA_1] if date==`l'
		quietly cap  replace slope0_`x'=_b[_cons] if date==`l'
	}	
}
* only keep one observation per month	
collapse (max) slope*,by(year month)
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m
	
sort year month	
cap drop D
egen D=group(year month)
tsset D
	
keep if inflation~=.&aggregate_disp_daily~=.
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
foreach x in 1 3 6 18{
	local z=`x'-1
	quietly{
	forvalues i=0(1)1{
		newey slope`i'_`x' aggregate_disp_daily, lag(`z') force
		estimates store A1_`i'_`x'
		newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x', lag(`z') force
		estimates store A2_`i'_`x'
		newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' dp inflation , lag(`z') force
		estimates store A3_`i'_`x'
		newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' dp inflation TED, lag(`z') force
		estimates store A4_`i'_`x'
	}
	}
}
	
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

*tables
foreach x in 1 3 6 18{
	estout A1_1_`x' A2_1_`x' A3_1_`x' A4_1_`x'  A1_0_`x' A2_0_`x' A3_0_`x' A4_0_`x' using ../tables/hong_table1_robust_`x'.tex, replace style(tex) label  keep(aggregate_disp_daily) mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
}



				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				*			DIFFERENT HORIZONS					 *
				**************************************************
* start from stock-level sample of 20-beta sorted portfolios with NYSE breakpoints
* value-weighted, daily betas
use "../output/sample_vw_all_beta_daily_breakpoint", replace	
drop if group==.
* collapse future returns at portfolio level
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)
gen BETA2=(BETA_1)^2

* cross-sectional regressions for different horizon
foreach x in 1 3 6 18{
	cap drop slope1_`x'
	gen slope1_`x'=.
	cap drop slope2_`x'
	gen slope2_`x'=.
	cap drop slope0_`x'=.
	gen slope0_`x'=.
	quietly levelsof date, local(levels)
	foreach l of local levels {
		quietly cap  reg ret_rf`x' BETA_1 BETA2 if date==`l' 
		quietly cap  replace slope1_`x'=_b[BETA_1] if date==`l'
		quietly cap  replace slope2_`x'=_b[BETA2] if date==`l'
		quietly cap  replace slope0_`x'=_b[_cons] if date==`l'
	}	
}	

* keep one observation per month
collapse (max) slope*,by(year month)
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D

keep if inflation~=.&aggregate_disp_daily~=.
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
foreach x in 1 3 6 18{
local z=`x'-1
quietly{
forvalues i=0(1)2{
newey slope`i'_`x' aggregate_disp_daily, lag(`z') force
estimates store A1_`i'_`x'
newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x', lag(`z') force
estimates store A2_`i'_`x'
newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' dp inflation , lag(`z') force
estimates store A3_`i'_`x'
newey slope`i'_`x' aggregate_disp_daily mktrf_`x' hml_`x' smb_`x' umd_`x' dp inflation TED, lag(`z') force
estimates store A4_`i'_`x'
}
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* tables
foreach x in 1 3 6 18{
	estout A1_2_`x' A2_2_`x' A3_2_`x' A4_2_`x' A1_1_`x' A2_1_`x' A3_1_`x' A4_1_`x'  A1_0_`x' A2_0_`x' A3_0_`x' A4_0_`x' using ../tables/hong_table2_robust_`x'.tex, replace style(tex) label  keep(aggregate_disp_daily) mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
}

				**************************************************
				* 		REFEREE TABLE FOR INTERACTIONS			 *
				*		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
gen inter1=aggregate_disp_daily*mktrf_12
label var inter1 "$\text{Agg. Disp.}_{t-1}\times\text{R}_{m,t}^{(12)}$"
gen inter2=aggregate_disp_daily*hml_12
label var inter2 "$\text{Agg. Disp.}_{t-1}\times\text{HML}_{m,t}^{(12)}$"
gen inter3=aggregate_disp_daily*smb_12
label var inter3 "$\text{Agg. Disp.}_{t-1}\times\text{SMB}_{m,t}^{(12)}$"
gen inter4=aggregate_disp_daily*umd_12
label var inter4 "$\text{Agg. Disp.}_{t-1}\times\text{UMD}_{m,t}^{(12)}$"


forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily mktrf_12 inter1 hml_12  inter2 smb_12 inter3  umd_12  inter4 , lag(11) force
 estimates store A1_`i'
 newey slope`i' aggregate_disp_daily mktrf_12 inter1 hml_12  inter2 smb_12 inter3  umd_12  inter4 dp inflation TED, lag(11) force
estimates store A2_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"


use "../output/sample_ew_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 , by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
gen inter1=aggregate_disp_daily*mktrf_12
label var inter1 "$\text{Agg. Disp.}_{t-1}\times\text{R}_{m,t}^{(12)}$"
gen inter2=aggregate_disp_daily*hml_12
label var inter2 "$\text{Agg. Disp.}_{t-1}\times\text{HML}_{m,t}^{(12)}$"
gen inter3=aggregate_disp_daily*smb_12
label var inter3 "$\text{Agg. Disp.}_{t-1}\times\text{SMB}_{m,t}^{(12)}$"
gen inter4=aggregate_disp_daily*umd_12
label var inter4 "$\text{Agg. Disp.}_{t-1}\times\text{UMD}_{m,t}^{(12)}$"


forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily mktrf_12 inter1 hml_12  inter2 smb_12 inter3  umd_12  inter4 , lag(11) force
 estimates store A3_`i'
 newey slope`i' aggregate_disp_daily mktrf_12 inter1 hml_12  inter2 smb_12 inter3  umd_12  inter4 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 using ../tables/hong_table_additional.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") drop(_cons)  stats(N, fmt(%9.0fc %9.2f))




	
				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				* 		CONTROLLING FOR PROFITABILITY FACTOR	 *
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1 [w=value], by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var pmu2_12 "$\text{PMU}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_tablepmu.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))

* equal-weighted panel
* use equal-weighted sample of beta-sorted portfolios
use "../output/sample_ew_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) ret_rf* BETA_1, by(group date year month)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var pmu_12 "$\text{PMU}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Equal-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_tablepmu_ew.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))

				**************************************************
				* 		TABLE: SML SLOPE AND DISAGREEMENT		 *
				* 		SPECULATIVE VS. NON SPECULATIVE STOCKS	 *
				* 		CONTROLLING FOR PROFITABILITY FACTOR	 *
				**************************************************

*** first, value weighted with median beta/sigma^2 as breakpoint
do construc_data1_breakpoints
construc_data1_breakpoints 50, value
* use 40 value-weighted sample of beta-sorted portfolios for spec and non-spec stocks
use "../output/sample_vw_50_daily_breakpoints", replace
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
* we use the median daily-volatility to characterize the volatility of stocks
* in each portfolio
collapse (median) sigma_daily (mean) ret_rf* SIGMA_1 BETA_1 [w=value] ,by(year month date group spec)
* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0
gen slope0=.
* define lsigma: ln of median daily volatility of stocks in portfolio
gen lsigma=ln(sigma_daily)
* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	forvalues p=0(1)1{
		* regress portfolio 12 months forward return on post-ranking portfolio beta
		* and ln of sigma, separately for speculative and non-speculative portfolios
		quietly cap  reg ret_rf12 BETA_1 lsigma if date==`l' &spec==`p' 
		quietly cap  replace slope1=_b[BETA_1] if date==`l'&spec==`p'
		quietly cap  replace slope2=_b[lsigma] if date==`l'&spec==`p'
		quietly cap  replace slope0=_b[_cons] if date==`l'&spec==`p'
	}
}	
* keep only one observation per month
collapse (max) slope1 slope2 slope0, by(date year month spec)
* drop in case it creates a spec=. category
drop if spec==.
* merge with time-series variables
sort year month
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset spec D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope of SML, slope of ln sigma and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues j=0(1)1{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily if spec==`j', lag(11) force
estimates store A1_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 pmu2_12 if spec==`j', lag(11) force
estimates store A2_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12  pmu2_12 dp inflation  if spec==`j', lag(11) force
estimates store A3_`j'_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12  pmu2_12 dp inflation TED  if spec==`j', lag(11) force
estimates store A4_`j'_`i'
}
}
}
* labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var pmu2_12 "$\text{PMU}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"
* creates two tables: spec stock panel; non-spec stock panel.
estout A1_1_1 A2_1_1 A3_1_1 A4_1_1 A1_1_2 A2_1_2 A3_1_2 A4_1_2  A1_1_0 A2_1_0 A3_1_0 A4_1_0 using ../tables/hong_table3pmu_1.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")
estout A1_0_1 A2_0_1 A3_0_1 A4_0_1  A1_0_2 A2_0_2 A3_0_2 A4_0_2  A1_0_0 A2_0_0 A3_0_0 A4_0_0 using ../tables/hong_table3pmu_2.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant") stats(N, fmt(%9.0fc %9.2f))


				**************************************************
				* 		FIGURE: STOCK DISAGREEMENT AND BETA		 *
				**************************************************
use "../output/sample_vw_all_beta_daily_breakpoint", replace	
collapse (mean) stdevwin (mean) ret_rf* SIGMA_1 BETA_1 [w=value] ,by(year month date group)
sort year month
merge m:1 year month using ../output/time_series
egen TT=xtile(aggregate_disp_daily), nq(4)

egen m1=mean(stdevwin),by(group TT)
label var m1 "Stock-level disagreement"
label var BETA_1 "Beta"
twoway (scatter m1 BETA_1 if TT==1)(scatter m1 BETA_1 if TT==4), legend(rows(1) order(1 "Low Disagreement" 2 "High Disagreement"))
gr export ../figures/dispersion.png





				********************************************************************************
				*			Descriptive Statistics Table									   *
				********************************************************************************

				
	***For time-series variables
use ../output/time_series, clear
keep if aggregate_disp_daily~=.&mktrf_12~=.
standardize aggregate_disp_daily 
standardize aggregate_disp_daily2
standardize aggregate_disp_daily3
standardize topdown_disag1 
standardize spf

foreach x in aggregate_disp_daily  aggregate_disp_daily2  aggregate_disp_daily3 topdown_disag1 spf mktrf_12 smb_12 hml_12 umd_12 dp inflation TED{

quietly xcollapse (count) N=`x' (mean) mm=`x'  (median) m=`x' (sd) s=`x' (p10) p1=`x'  (p25) p2=`x' (p75) p3=`x' (p90) p4=`x' , format(mm m s p* %9.2fc N %9.0fc) saving(../output/`x'_STAT,replace)
}

clear
use  ../output/aggregate_disp_daily_STAT, replace

foreach x in aggregate_disp_daily2  aggregate_disp_daily3 topdown_disag1 spf mktrf_12 smb_12 hml_12 umd_12 dp inflation TED{
quietly append using ../output/`x'_STAT
}


gen name=_n

label define mylabel 1 "Agg. Disp.", replace
label define mylabel 2 "Agg. Disp. (compressed) "  3 "$\text{Agg. Disp.}~(\beta\times\text{~Value weight})$" 4 "Top-down Disp." 5 "SPF Disp." 6 "$\text{R}_{m,t}^{(12)}$" 7 "$\text{SMB}_{t}^{(12)}$" 8 "$\text{HML}_{t}^{(12)}$" 9 "$\text{UMD}_{t}^{(12)}$" 10 "D/P" 11 "Inflation" 12 "TED spread", add
label values name mylabel

listtab name mm s p1 p2 m  p3 p4 N using "../tables/table1_1.tex", rstyle(tabular) replace  

	*** For beta-sorted portfolios
	
use "../output/sample_vw_all_beta_daily_breakpoint", replace	
sort year month
merge m:1 year month using ../output/time_series
drop if _m==2
drop _m
keep if aggregate_disp_daily~=.
egen s=sum(value),by(group date)
egen S=sum(value),by(date)
gen percent=s/S
egen PERCENT=mean(s/S),by(group)
replace PERCENT=100*PERCENT
egen N=count(ret_rf1), by(group date)
egen NN=median(N), by(group)
collapse (median) sigma_daily (mean) NN PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 [w=value], by(group)
foreach x in sigma_daily PERCENT BETA_1 stdevwin ret_rf1  ret_rf12{
format `x' %9.2f
}
format NN %9.0f
xpose, clear varname promote
foreach x in sigma_daily PERCENT BETA_1 stdevwin ret_rf1  ret_rf12{
forvalues i=1(1)20{
replace v`i'=int(v`i'*100)/100 if _varname=="`x'"
}
}
gen temp=.
drop if _varname=="group"
replace _varname="$\beta$" if _varname=="BETA_1"
replace temp=1 if _varname=="$\beta$"
foreach x in 1 12 {
replace _varname="$\text{R}_{i,t}^{(`x')}$" if _varname=="ret_rf`x'"
replace temp=1+`x' if _varname=="$\text{R}_{i,t}^{(`x')}$"
}
replace _varname="Stock Disp." if _varname=="stdevwin"
replace temp=20 if _varname=="Stock Disp."
replace _varname="Median Vol." if _varname=="sigma_daily"
replace temp=1.5 if _varname=="Median Vol."
replace _varname="\% Mkt. Cap." if _varname=="PERCENT"
replace temp=21 if _varname=="\% Mkt. Cap."
replace _varname="N stocks" if _varname=="NN"
replace temp=22 if _varname=="N stocks"

ren _varname v0
order v0
sort temp
drop temp
listtab using "../tables/table1_2.tex" , rstyle(tabular) replace  



	
use "../output/sample_vw_50_daily_breakpoints", replace
sort year month
merge m:1 year month using ../output/time_series
drop if _m==2
drop _m
keep if aggregate_disp_daily~=.
keep if spec==0
egen s=sum(value),by(group date)
egen S=sum(value),by(date)
gen percent=s/S
egen PERCENT=mean(s/S),by(group)
replace PERCENT=100*PERCENT
egen N=count(ret_rf1), by(group date)
egen NN=median(N), by(group)
collapse (median) sigma_daily (mean) NN PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 [w=value], by(group)
gen ratio=BETA_1/(sigma_daily^2)
foreach x in sigma_daily PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 ratio{
format `x' %9.2f
}
format NN %9.0f
xpose, clear varname promote
foreach x in sigma_daily PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 ratio{
forvalues i=1(1)20{
replace v`i'=int(v`i'*100)/100 if _varname=="`x'"
}
}
gen temp=.
drop if _varname=="group"
replace _varname="$\beta$" if _varname=="BETA_1"
replace temp=1 if _varname=="$\beta$"
foreach x in 1 12 {
replace _varname="$\text{R}_{i,t}^{(`x')}$" if _varname=="ret_rf`x'"
replace temp=1+`x' if _varname=="$\text{R}_{i,t}^{(`x')}$"
}
replace _varname="Stock Disp." if _varname=="stdevwin"
replace temp=20 if _varname=="Stock Disp."
replace _varname="Median Vol." if _varname=="sigma_daily"
replace temp=1.5 if _varname=="Median Vol."
replace _varname="\% Mkt. Cap." if _varname=="PERCENT"
replace temp=1.75 if _varname=="ratio"
replace _varname="$\frac{\beta}{\sigma^2}$" if _varname=="ratio"
replace temp=21 if _varname=="\% Mkt. Cap."
replace _varname="N stocks" if _varname=="NN"
replace temp=22 if _varname=="N stocks"

ren _varname v0
order v0
sort temp
drop temp
listtab using "../tables/table1_3.tex" , rstyle(tabular) replace  


	
	
use "../output/sample_vw_50_daily_breakpoints", replace
sort year month
merge m:1 year month using ../output/time_series
drop if _m==2
drop _m
keep if aggregate_disp_daily~=.
keep if spec==1
egen s=sum(value),by(group date)
egen S=sum(value),by(date)
gen percent=s/S
egen PERCENT=mean(s/S),by(group)
replace PERCENT=100*PERCENT
egen N=count(ret_rf1), by(group date)
egen NN=median(N), by(group)
collapse (median) sigma_daily (mean) NN PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 [w=value], by(group)
gen ratio=BETA_1/(sigma_daily^2)
foreach x in sigma_daily PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 ratio{
format `x' %9.2f
}
format NN %9.0f
xpose, clear varname promote
foreach x in sigma_daily PERCENT BETA_1 stdevwin ret_rf1  ret_rf12 ratio{
forvalues i=1(1)20{
replace v`i'=int(v`i'*100)/100 if _varname=="`x'"
}
}
gen temp=.
drop if _varname=="group"
replace _varname="$\beta$" if _varname=="BETA_1"
replace temp=1 if _varname=="$\beta$"
foreach x in 1 12 {
replace _varname="$\text{R}_{i,t}^{(`x')}$" if _varname=="ret_rf`x'"
replace temp=1+`x' if _varname=="$\text{R}_{i,t}^{(`x')}$"
}
replace _varname="Stock Disp." if _varname=="stdevwin"
replace temp=20 if _varname=="Stock Disp."
replace _varname="Median Vol." if _varname=="sigma_daily"
replace temp=1.5 if _varname=="Median Vol."
replace _varname="\% Mkt. Cap." if _varname=="PERCENT"
replace temp=1.75 if _varname=="ratio"
replace _varname="$\frac{\beta}{\sigma^2}$" if _varname=="ratio"
replace temp=21 if _varname=="\% Mkt. Cap."
replace _varname="N stocks" if _varname=="NN"
replace temp=22 if _varname=="N stocks"

ren _varname v0
order v0
sort temp
drop temp
listtab using "../tables/table1_4.tex" , rstyle(tabular) replace  

	
				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				* 		CONTROLLING FOR STOCK DISPERSION		*
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) stdevwin ret_rf* BETA_1 [w=value], by(group date year month)

gen lstdevwin=ln(stdevwin)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 lstdevwin if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2]  if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1_disp.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

* equal-weighted panel
* use equal-weighted sample of beta-sorted portfolios
use "../output/sample_ew_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (mean) stdevwin ret_rf* BETA_1, by(group date year month)
gen lstdevwin=ln(stdevwin)
* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 lstdevwin if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Equal-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1_ew_disp.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))


	
				**************************************************
				* 		TABLE: SML CONCAVITY AND DISAGREEMENT	 *
				* 		CONTROLLING FOR STOCK volatility		*
				**************************************************

* first, value-weighted panel
* use value-weighted portfolios

use "../output/sample_vw_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using current month value weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (median) sigma_daily (mean) stdevwin ret_rf* BETA_1 [w=value], by(group date year month)

gen lstdevwin=ln(sigma_daily)

* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 lstdevwin if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2]  if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Value-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1_vol.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")

* equal-weighted panel
* use equal-weighted sample of beta-sorted portfolios
use "../output/sample_ew_all_beta_daily_breakpoint", replace	
* drop if no portfolio attribution
drop if group==.
* collapse returns at the portfolio level, using no weight
* note that BETA_1 is post-ranking beta, so constant by group.
collapse (median) sigma_daily (mean) stdevwin ret_rf* BETA_1, by(group date year month)
gen lstdevwin=ln(sigma_daily)
* Construct square of full-sample post-ranking beta
gen BETA2=(BETA_1)^2

* define slope1, slope2 and slope0
cap drop slope1
gen slope1=.
cap drop slope2
gen slope2=.
cap drop slope0=.
gen slope0=.

* loop over months -- cross-sectional regressions
quietly levelsof date, local(levels)
foreach l of local levels {
	* regress portfolio 12 months forward return on post-ranking portfolio beta
	* and beta^2
	quietly cap  reg ret_rf12 BETA_1 BETA2 lstdevwin if date==`l' 
	* slope1 is the linear slope
	quietly cap  replace slope1=_b[BETA_1] if date==`l'
	* slope2 is the quadratic coefficient
	quietly cap  replace slope2=_b[BETA2] if date==`l'
	* slope0 is the intercept
	quietly cap  replace slope0=_b[_cons] if date==`l'
}	

* only keep one observation per month
collapse (max) slope1 slope2 slope0, by(year month)
sort year month
* merge with time-series variables
merge m:1 year month using "../output/time_series"
drop if _m==2
drop _m

sort year month	
cap drop D
egen D=group(year month)
tsset D
* keep if non-missing slope, inflation and disagreement variable
keep if slope1~=.&inflation~=.&aggregate_disp_daily~=.
* standardize time-series variable over final sample
standardize aggregate_disp_daily
standardize dp 
standardize inflation
standardize TED
* regress slope, quadratic and intercept on aggregate disp.
* and other time-series variables
quietly{
forvalues i=0(1)2{
newey slope`i' aggregate_disp_daily, lag(11) force
estimates store A1_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12, lag(11) force
estimates store A2_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation , lag(11) force
estimates store A3_`i'
newey slope`i' aggregate_disp_daily mktrf_12 hml_12 smb_12 umd_12 dp inflation TED, lag(11) force
estimates store A4_`i'
}
}
*labels
label var aggregate_disp_daily "$\text{Agg. Disp.}_{t-1}$"
label var mktrf_12 "$\text{R}_{m,t}^{(12)}$"
label var hml_12 "$\text{HML}_{t}^{(12)}$"
label var smb_12 "$\text{SMB}_{t}^{(12)}$"
label var umd_12 "$\text{UMD}_{t}^{(12)}$"
label var inflation "$\text{Inflation}_{t-1}$"
label var dp "$\text{D/P}_{t-1}$"
label var TED "$\text{Ted Spread}_{t-1}$"

* Equal-weighted panel of table
estout A1_2 A2_2 A3_2 A4_2 A1_1 A2_1 A3_1 A4_1  A1_0 A2_0 A3_0 A4_0 using ../tables/hong_table1_ew_vol.tex, replace style(tex) label  mlabels(none) collabel(none)  cells(b(fmt(%9.2g) star )  t(fmt(%9.2g) par)) eqlabel(none) starlevels(* .10 ** .05 *** .01) varlabel(_cons "Constant")  stats(N, fmt(%9.0fc %9.2f))


	
